@@ -938,8 +938,8 @@ bool RclConfig::getMissingHelperDesc(string& out) const
 void RclConfig::storeMissingHelperDesc(const string &s)
 {
     string fmiss = path_cat(getCacheDir(), "missing");
-    fstream fp = path_open(fmiss, ios::trunc | ios::out);
-    if (fp.is_open()) {
+    fstream fp;
+    if (path_streamopen(fmiss, ios::trunc | ios::out, fp)) {
         fp << s;
     }
 }
@@ -1115,20 +1115,19 @@ set<string> RclConfig::getIndexedFields() const
 string RclConfig::fieldCanon(const string& f) const
 {
     string fld = stringtolower(f);
-    map<string, string>::const_iterator it = m_aliastocanon.find(fld);
+    const auto it = m_aliastocanon.find(fld);
     if (it != m_aliastocanon.end()) {
         LOGDEB1("RclConfig::fieldCanon: [" << f << "] -> [" << it->second <<
                 "]\n");
         return it->second;
     }
-    LOGDEB1("RclConfig::fieldCanon: ["  << (f) << "] -> ["  << (fld) << "]\n");
+    LOGDEB1("RclConfig::fieldCanon: [" << f << "] -> [" << fld << "]\n");
     return fld;
 }
 
 string RclConfig::fieldQCanon(const string& f) const
 {
-    string fld = stringtolower(f);
-    map<string, string>::const_iterator it = m_aliastoqcanon.find(fld);
+    const auto it = m_aliastoqcanon.find(stringtolower(f));
     if (it != m_aliastoqcanon.end()) {
         LOGDEB1("RclConfig::fieldQCanon: [" << f << "] -> ["  << it->second <<
                 "]\n");
@@ -1161,7 +1160,7 @@ set<string> RclConfig::getMimeViewerAllEx() const
 
     string base, plus, minus;
     mimeview->get("xallexcepts", base, "");
-    LOGDEB1("RclConfig::getMimeViewerAllEx(): base: " << s << endl);
+    LOGDEB1("RclConfig::getMimeViewerAllEx(): base: " << base << endl);
     mimeview->get("xallexcepts+", plus, "");
     LOGDEB1("RclConfig::getMimeViewerAllEx(): plus: " << plus << endl);
     mimeview->get("xallexcepts-", minus, "");
@@ -1375,9 +1374,9 @@ string RclConfig::getStopfile() const
     return getConfdirPath("stoplistfile", "stoplist.txt");
 }
 
-string RclConfig::getSynGroupsFile() const
+string RclConfig::getIdxSynGroupsFile() const
 {
-    return getConfdirPath("syngroupsfile", "syngroups.txt");
+    return getConfdirPath("idxsynonyms", "thereisnodefaultidxsynonyms");
 }
 
 // The index status file is fast changing, so it's possible to put it outside
@@ -1396,11 +1395,14 @@ string RclConfig::getPidfile() const
 {
     const char *p = getenv("XDG_RUNTIME_DIR");
     if (p) {
-	string base = path_canon(p);
-	string digest;
-	return path_cat(
-            base, "/recoll-" + MD5HexPrint(getConfDir(), digest) + "-index.pid");
-    }
+        string base = path_canon(p);
+        string digest, hex;
+        string cfdir = path_canon(getConfDir());
+        path_catslash(cfdir);
+        MD5String(cfdir, digest);
+        MD5HexPrint(digest, hex);
+        return path_cat(base, "/recoll-" + hex + "-index.pid");
+    } 
     return path_cat(getCacheDir(), "index.pid");
 }
 
@@ -1674,6 +1676,50 @@ string RclConfig::findFilter(const string &icmd) const
     }
 }
 
+bool RclConfig::processFilterCmd(std::vector<std::string>& cmd) const
+{
+    LOGDEB0("processFilterCmd: in: " << stringsToString(cmd) << "\n");
+    auto it = cmd.begin();
+
+    // Special-case python and perl on windows: we need to also locate the
+    // first argument which is the script name "python somescript.py". 
+    // On Unix, thanks to #!, we usually just run "somescript.py", but need
+    // the same change if we ever want to use the same cmd line as windows
+    bool hasinterp = !stringlowercmp("python", *it) ||
+        !stringlowercmp("perl", *it);
+
+    // Note that, if the cmd vector size is 1, post-incrementing the
+    // iterator in the following statement, which works on x86, leads
+    // to a crash on ARM with gcc 6 and 8 (at least), which does not
+    // seem right (it should just become cmd.end() ?) but
+    // whatever... We do it later then.
+    *it = findFilter(*it);
+
+    if (hasinterp) {
+        if (cmd.size() < 2) {
+            LOGERR("processFilterCmd: python/perl cmd: no script?. [" <<
+                   stringsToString(cmd) << "]\n");
+            return false;
+        } else {
+            ++it;
+            *it = findFilter(*it);
+        }
+    }
+    LOGDEB0("processFilterCmd: out: " << stringsToString(cmd) << "\n");
+    return true;
+}
+
+bool RclConfig::pythonCmd(const std::string& scriptname,
+                          std::vector<std::string>& cmd) const
+{
+#ifdef _WIN32
+    cmd = {"python", scriptname};
+#else
+    cmd = {scriptname};
+#endif
+    return processFilterCmd(cmd);
+}
+
 /** 
  * Return decompression command line for given mime type
  */
@@ -1690,32 +1736,14 @@ bool RclConfig::getUncompressor(const string &mtype, vector<string>& cmd) const
         LOGERR("getUncompressor: empty spec for mtype " << mtype << "\n");
         return false;
     }
-    vector<string>::iterator it = tokens.begin();
+    auto it = tokens.begin();
     if (tokens.size() < 2)
         return false;
     if (stringlowercmp("uncompress", *it++)) 
         return false;
     cmd.clear();
-    cmd.push_back(findFilter(*it));
-
-    // Special-case python and perl on windows: we need to also locate the
-    // first argument which is the script name "python somescript.py". 
-    // On Unix, thanks to #!, we usually just run "somescript.py", but need
-    // the same change if we ever want to use the same cmdling as windows
-    if (!stringlowercmp("python", *it) || !stringlowercmp("perl", *it)) {
-        it++;
-        if (tokens.size() < 3) {
-            LOGERR("getUncpressor: python/perl cmd: no script?. [" <<
-                   mtype << "]\n");
-        } else {
-            *it = findFilter(*it);
-        }
-    } else {
-        it++;
-    }
-    
     cmd.insert(cmd.end(), it, tokens.end());
-    return true;
+    return processFilterCmd(cmd);
 }
 
 static const char blurb0[] = 
@@ -1765,8 +1793,8 @@ bool RclConfig::initUserConfig()
     for (int i = 0; i < ncffiles; i++) {
         string dst = path_cat(m_confdir, string(configfiles[i])); 
         if (!path_exists(dst)) {
-            fstream output = path_open(dst, ios::out);
-            if (output.is_open()) {
+            fstream output;
+            if (path_streamopen(dst, ios::out, output)) {
                 output << blurb << "\n";
                 if (!strcmp(configfiles[i], "recoll.conf")) {
                     // Add improved unac_except_trans for some languages
