@@ -84,6 +84,9 @@ int           TextSplit::o_maxWordLength{40};
 static const int o_CJKMaxNgramLen{5};
 bool o_exthangultagger{false};
 
+// This is changed to 0 if _ is processed as a letter
+static char underscoreatend = '_';
+
 void TextSplit::staticConfInit(RclConfig *config)
 {
     config->getConfParam("maxtermlength", &o_maxWordLength);
@@ -118,6 +121,14 @@ void TextSplit::staticConfInit(RclConfig *config)
         }
     }
 
+    bvalue = false;
+    if (config->getConfParam("underscoreasletter", &bvalue)) {
+        if (bvalue) {
+            charclasses[int('_')] = A_LLETTER;
+            underscoreatend = 0;
+        }
+    }
+
     string kotagger;
     config->getConfParam("hangultagger", kotagger);
     if (!kotagger.empty()) {
@@ -521,60 +532,60 @@ inline bool TextSplit::doemit(bool spanerase, size_t _bp)
     if (m_wordLen) {
         // We have a current word. Remember it
 
-        // Limit max span word count
         if (m_words_in_span.size() >= 6) {
+            // Limit max span word count
             spanerase = true;
-        } 
-
-        m_words_in_span.push_back(pair<int,int>(m_wordStart, 
-                                                m_wordStart + m_wordLen));
-        m_wordpos++;
+        }
+        
+        if (!(o_noNumbers && m_inNumber)) {
+            m_words_in_span.push_back({m_wordStart, m_wordStart + m_wordLen});
+            m_wordpos++;
+        }
         m_wordLen = m_wordChars = 0;
     }
 
-    if (spanerase) {
-        // We encountered a span-terminating character. Produce terms.
-
-        string acronym;
-        if (span_is_acronym(&acronym)) {
-            if (!emitterm(false, acronym, m_spanpos, bp - m_span.length(), bp))
-                return false;
-        }
-
-        // Maybe trim at end. These are chars that we might keep
-        // inside a span, but not at the end.
-        while (m_span.length() > 0) {
-            switch (*(m_span.rbegin())) {
-            case '.':
-            case '-':
-            case ',':
-            case '@':
-            case '_':
-            case '\'':
-                m_span.resize(m_span.length()-1);
-                if (m_words_in_span.size() &&
-                    m_words_in_span.back().second > int(m_span.size()))
-                    m_words_in_span.back().second = int(m_span.size());
-                if (--bp < 0) 
-                    bp = 0;
-                break;
-            default:
-                goto breaktrimloop;
-            }
-        }
-    breaktrimloop:
-
-        if (!words_from_span(bp)) {
-            return false;
-        }
-        discardspan();
-
-    } else {
-    
+    if (!spanerase) {
+        // Not done with this span. Just update relative word start offset.
         m_wordStart = int(m_span.length());
-
+        return true;
     }
 
+
+    // Span is done (too long or span-terminating character). Produce
+    // terms and reset it.
+    string acronym;
+    if (span_is_acronym(&acronym)) {
+        if (!emitterm(false, acronym, m_spanpos, bp - m_span.length(), bp))
+            return false;
+    }
+
+    // Maybe trim at end. These are chars that we might keep
+    // inside a span, but not at the end.
+    string::size_type trimsz{0};
+    while (trimsz < m_span.length()) {
+        auto c = m_span[m_span.length() - 1 - trimsz];
+        if (c == '.' || c == '-' || c == ',' || c == '@' || c == '\'' ||
+            c == underscoreatend) {
+            trimsz++;
+            if (m_words_in_span.size() &&
+                m_words_in_span.back().second > int(m_span.size())) {
+                m_words_in_span.back().second = int(m_span.size());
+            }
+            if (--bp < 0) {
+                bp = 0;
+            }
+        } else {
+            break;
+        }
+    }
+    if (trimsz > 0) {
+        m_span.resize(m_span.length() - trimsz);
+    }
+
+    if (!words_from_span(bp)) {
+        return false;
+    }
+    discardspan();
     return true;
 }
 
@@ -673,7 +684,7 @@ bool TextSplit::text_to_words(const string &in)
                     return false;
                 }
             } else {
-                if (!cjk_to_words(&it, &c)) {
+                if (!cjk_to_words(it, &c)) {
                     LOGERR("Textsplit: scan error in cjk handler\n");
                     return false;
                 }
@@ -855,7 +866,7 @@ bool TextSplit::text_to_words(const string &in)
             goto SPACE;
 
         case '@':
-        case '_':
+        case '_': // If underscoreasletter is set, we'll never get this
         case '\'':
             // If in word, potential span: o'brien, jf@dockes.org,
             // else just ignore
@@ -982,9 +993,6 @@ bool TextSplit::text_to_words(const string &in)
     return true;
 }
 
-// Using an utf8iter pointer just to avoid needing its definition in
-// textsplit.h
-//
 // We output ngrams for exemple for char input a b c and ngramlen== 2, 
 // we generate: a ab b bc c as words
 //
@@ -993,10 +1001,9 @@ bool TextSplit::text_to_words(const string &in)
 //
 // The routine is sort of a mess and goes to show that we'd probably
 // be better off converting the whole buffer to utf32 on entry...
-bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
+bool TextSplit::cjk_to_words(Utf8Iter& it, unsigned int *cp)
 {
     LOGDEB1("cjk_to_words: m_wordpos " << m_wordpos << "\n");
-    Utf8Iter &it = *itp;
 
     // We use an offset buffer to remember the starts of the utf-8
     // characters which we still need to use.
@@ -1008,12 +1015,18 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
     // Current number of valid offsets;
     unsigned int nchars = 0;
     unsigned int c = 0;
+    bool spacebefore{false};
     for (; !it.eof() && !it.error(); it++) {
         c = *it;
         // We had a version which ignored whitespace for some time,
-        // but this was a bad idea. Only break on an non-cjk
-        // alphabetic character.
-        if (!UNICODE_IS_CJK(c) && (c > 255 || isalpha(c))) {
+        // but this was a bad idea. Only break on a non-cjk
+        // *alphabetic* character, except if following punctuation, in
+        // which case we return for any non-cjk. This allows compound
+        // cjk+numeric spans, or punctuated cjk spans to be
+        // continually indexed as cjk. The best approach is a matter
+        // of appreciation...
+        if (!UNICODE_IS_CJK(c) &&
+            (spacebefore || (c > 255 || isalpha(c)))) {
             // Return to normal handler
             break;
         }
@@ -1021,7 +1034,10 @@ bool TextSplit::cjk_to_words(Utf8Iter *itp, unsigned int *cp)
             // Flush the ngram buffer and go on
             nchars = 0;
             mybuf.clear();
+            spacebefore = true;
             continue;
+        } else {
+            spacebefore = false;
         }
         if (nchars == o_CJKNgramLen) {
             // Offset buffer full, shift it. Might be more efficient
