@@ -71,7 +71,6 @@ static int     op_flags;
 #define OPT_R 0x20    
 #define OPT_S 0x40    
 #define OPT_Z 0x80    
-#define OPT_b 0x100   
 #define OPT_c 0x200   
 #define OPT_e 0x400   
 #define OPT_f 0x800   
@@ -119,8 +118,7 @@ public:
         }
     }
 
-    virtual bool update() 
-    {
+    virtual bool update() {
         // Update the status file. Avoid doing it too often. Always do
         // it at the end (status DONE)
         if (status.phase == DbIxStatus::DBIXS_DONE || 
@@ -263,8 +261,8 @@ class MakeListWalkerCB : public FsTreeWalkerCB {
 public:
     MakeListWalkerCB(list<string>& files, const vector<string>& selpats)
         : m_files(files), m_pats(selpats)
-    {
-    }
+        {
+        }
     virtual FsTreeWalker::Status 
     processone(const string& fn, const struct PathStat *,
                FsTreeWalker::CbFlag flg) {
@@ -398,7 +396,8 @@ static bool checktopdirs(RclConfig *config, vector<string>& nonexist)
             }
         }
     }
-    
+
+    bool onegood{false};
     for (auto& dir : o_topdirs) {
         dir = path_tildexpand(dir);
         if (!dir.size() || !path_isabsolute(dir)) {
@@ -413,6 +412,8 @@ static bool checktopdirs(RclConfig *config, vector<string>& nonexist)
         }
         if (!path_exists(dir)) {
             nonexist.push_back(dir);
+        } else {
+            onegood = true;
         }
     }
     topdirs_state(o_topdirs_emptiness);
@@ -420,7 +421,7 @@ static bool checktopdirs(RclConfig *config, vector<string>& nonexist)
     // We'd like to check skippedPaths too, but these are wildcard
     // exprs, so reasonably can't
 
-    return true;
+    return onegood;
 }
 
 
@@ -474,7 +475,7 @@ static const char usage [] =
 #endif
 "Common options:\n"
 "    -c <configdir> : specify config directory, overriding $RECOLL_CONFDIR\n"
-;
+                                                           ;
 
 static void Usage()
 {
@@ -559,7 +560,7 @@ static void flushIdxReasons()
 static vector<string> argstovector(int argc, wchar_t **argv)
 #else
 #define WARGTOSTRING(w) (w)
-static vector<string> argstovector(int argc, char **argv)
+    static vector<string> argstovector(int argc, char **argv)
 #endif
 {
     thisprog = path_absolute(WARGTOSTRING(argv[0]));
@@ -585,6 +586,10 @@ static vector<string> fileToArgs(const string& fn)
 }
 
 
+// Working directory before we change: it's simpler to change early
+// but some options need the original for computing absolute paths.
+static std::string orig_cwd;
+
 // A bit of history: it's difficult to pass non-ASCII parameters
 // (e.g. path names) on the command line under Windows without using
 // Unicode. It was first thought possible to use a temporary file to
@@ -598,10 +603,10 @@ int wmain(int argc, wchar_t *argv[])
 int main(int argc, char *argv[])
 #endif
 {
+#ifndef _WIN32
     // The reexec struct is used by the daemon to shed memory after
     // the initial indexing pass and to restart when the configuration
     // changes
-#ifndef _WIN32
     o_reexec = new ReExec;
     o_reexec->init(argc, argv);
 #endif
@@ -609,7 +614,8 @@ int main(int argc, char *argv[])
     vector<string> args = argstovector(argc, argv);
 
     // Passing args through a temp file: this is used on Windows to
-    // avoid issues with charsets in args (avoid using wmain)
+    // avoid issues with charsets in args (thought to avoid using
+    // wmain, which proved false, but the args file was kept)
     if (args.size() == 1 && args[0][0] != '-') {
         args = fileToArgs(args[0]);
     }
@@ -627,7 +633,6 @@ int main(int argc, char *argv[])
         }
         for (unsigned int cidx = 1; cidx < arg.size(); cidx++) {
             switch (arg[cidx]) {
-            case 'b': op_flags |= OPT_b; break;
             case 'c':   op_flags |= OPT_c; if (aremain < 2)  Usage();
                 a_config = args[argidx+1]; argidx++; goto b1;
 #ifdef RCL_MONITOR
@@ -671,9 +676,10 @@ int main(int argc, char *argv[])
 
     if (op_flags & OPT_h)
         Usage();
+
 #ifndef RCL_MONITOR
     if (op_flags & (OPT_m | OPT_w|OPT_x)) {
-        cerr << "Sorry, -m not available: real-time monitoring was not "
+        cerr << "-m not available: real-time monitoring was not "
             "configured in this build\n";
         exit(1);
     }
@@ -705,7 +711,8 @@ int main(int argc, char *argv[])
 
     vector<string> nonexist;
     if (!checktopdirs(config, nonexist)) {
-        addIdxReason("init", "topdirs not set");
+        std::cerr << "topdirs not set or only contains invalid paths.\n";
+        addIdxReason("init", "topdirs not set or only contains invalid paths.");
         flushIdxReasons();
         exit(1);
     }
@@ -716,15 +723,25 @@ int main(int argc, char *argv[])
             cerr << "Warning: invalid paths in topdirs, skippedPaths or "
                 "daemSkippedPaths:\n";
         }
-        for (vector<string>::const_iterator it = nonexist.begin(); 
-             it != nonexist.end(); it++) {
-            out << *it << endl;
+        for (const auto& entry : nonexist) {
+            out << entry << endl;
         }
     }
     if ((op_flags & OPT_E)) {
         exit(0);
     }
 
+    if (op_flags & OPT_l) {
+        if (aremain != 0) 
+            Usage();
+        vector<string> stemmers = ConfIndexer::getStemmerNames();
+        for (const auto& stemmer : stemmers) {
+            cout << stemmer << endl;
+        }
+        exit(0);
+    }
+    
+    orig_cwd = path_cwd();
     string rundir;
     config->getConfParam("idxrundir", rundir);
     if (!rundir.empty()) {
@@ -765,6 +782,7 @@ int main(int argc, char *argv[])
 
     Pidfile pidfile(config->getPidfile());
     updater = new MyUpdater(config);
+    lockorexit(&pidfile, config);
 
     // Log something at LOGINFO to reset the trace file. Else at level
     // 3 it's not even truncated if all docs are up to date.
@@ -775,6 +793,7 @@ int main(int argc, char *argv[])
         if (aremain != 1) 
             Usage();
         string top = args[argidx++]; aremain--;
+        top = path_canon(top, &orig_cwd);
         bool status = recursive_index(config, top, selpatterns);
         if (confindexer && !confindexer->getReason().empty()) {
             addIdxReason("indexer", confindexer->getReason());
@@ -783,8 +802,6 @@ int main(int argc, char *argv[])
         flushIdxReasons();
         exit(status ? 0 : 1);
     } else if (op_flags & (OPT_i|OPT_e)) {
-        lockorexit(&pidfile, config);
-
         list<string> filenames;
         if (aremain == 0) {
             // Read from stdin
@@ -816,20 +833,12 @@ int main(int argc, char *argv[])
         }
         flushIdxReasons();
         exit(status ? 0 : 1);
-    } else if (op_flags & OPT_l) {
-        if (aremain != 0) 
-            Usage();
-        vector<string> stemmers = ConfIndexer::getStemmerNames();
-        for (vector<string>::const_iterator it = stemmers.begin(); 
-             it != stemmers.end(); it++) {
-            cout << *it << endl;
-        }
-        exit(0);
     } else if (op_flags & OPT_s) {
         if (aremain != 1) 
             Usage();
         string lang = args[argidx++]; aremain--;
         exit(!createstemdb(config, lang));
+
 #ifdef RCL_USE_ASPELL
     } else if (op_flags & OPT_S) {
         makeIndexerOrExit(config, false);
@@ -840,7 +849,6 @@ int main(int argc, char *argv[])
     } else if (op_flags & OPT_m) {
         if (aremain != 0) 
             Usage();
-        lockorexit(&pidfile, config);
         if (updater) {
             updater->status.hasmonitor = true;
         }
@@ -919,30 +927,25 @@ int main(int argc, char *argv[])
         exit(monret == false);
 #endif // MONITOR
 
-    } else if (op_flags & OPT_b) {
-        cerr << "Not yet" << endl;
-        return 1;
-    } else {
-        lockorexit(&pidfile, config);
-        makeIndexerOrExit(config, inPlaceReset);
-        bool status = confindexer->index(rezero, ConfIndexer::IxTAll, 
-                                         indexerFlags);
-        // Record success of indexing pass with failed files retries.
-        if (status && !(indexerFlags & ConfIndexer::IxFNoRetryFailed)) {
-            checkRetryFailed(config, true);
-        }
-        if (!status) 
-            cerr << "Indexing failed" << endl;
-        if (!confindexer->getReason().empty()) {
-            addIdxReason("indexer", confindexer->getReason());
-            cerr << confindexer->getReason() << endl;
-        }
-        if (updater) {
-            updater->status.phase = DbIxStatus::DBIXS_DONE;
-            updater->status.fn.clear();
-            updater->update();
-        }
-        flushIdxReasons();
-        return !status;
     }
+
+    makeIndexerOrExit(config, inPlaceReset);
+    bool status = confindexer->index(rezero, ConfIndexer::IxTAll, indexerFlags);
+    // Record success of indexing pass with failed files retries.
+    if (status && !(indexerFlags & ConfIndexer::IxFNoRetryFailed)) {
+        checkRetryFailed(config, true);
+    }
+    if (!status) 
+        cerr << "Indexing failed" << endl;
+    if (!confindexer->getReason().empty()) {
+        addIdxReason("indexer", confindexer->getReason());
+        cerr << confindexer->getReason() << endl;
+    }
+    if (updater) {
+        updater->status.phase = DbIxStatus::DBIXS_DONE;
+        updater->status.fn.clear();
+        updater->update();
+    }
+    flushIdxReasons();
+    return !status;
 }
