@@ -559,6 +559,13 @@ bool FileInterner::dijontorcl(Rcl::Doc& doc)
             const string *fnp = 0;
             if (!doc.peekmeta(Rcl::Doc::keyfn, &fnp) || fnp->empty())
                 doc.meta[Rcl::Doc::keyfn] = ent.second;
+        } else if (ent.first == cstr_dj_keymd5) {
+            // Only if not set during the stack walk: we want the md5
+            // from the actual document, not from further conversions,
+            // as computed, e.g. by the html to text handler
+            const string *val = 0;
+            if (!doc.peekmeta(Rcl::Doc::keymd5, &val) || val->empty())
+                doc.meta[Rcl::Doc::keymd5] = ent.second;
         } else if (ent.first == cstr_dj_keymt || 
                    ent.first == cstr_dj_keycharset) {
             // don't need/want these.
@@ -932,7 +939,10 @@ breakloop:
     }
     // Keep this AFTER collectIpathAndMT
     dijontorcl(doc);
-
+    // Fix the bogus mtype used to force mh_text processing of text subdocs
+    if (doc.mimetype == "text/plain1") {
+        doc.mimetype = "text/plain";
+    }
     // Possibly destack so that we can test for FIDone. While doing this
     // possibly set aside an ancestor html text (for the GUI preview)
     while (!m_handlers.empty() && !m_handlers.back()->has_documents()) {
