@@ -32,6 +32,7 @@ using namespace std;
 #include "rclconfig.h"
 #include "mimetype.h"
 #include "idfile.h"
+#include "rclutil.h"
 
 #include <sys/types.h>
 #include "safesyswait.h"
@@ -150,7 +151,7 @@ bool MimeHandlerExecMultiple::readDataElement(string& name, string &data)
     }
     LOGDEB1("MHExecMe:rdDtElt got: name [" << name << "] len " << len <<
             "value [" << (datap->size() > 100 ? 
-                          (datap->substr(0, 100) + " ...") : datap) << endl);
+                          (datap->substr(0, 100) + " ...") : *datap) << endl);
     return true;
 }
 
@@ -266,11 +267,7 @@ bool MimeHandlerExecMultiple::next_document()
             string nm = stringtolower((const string&)name);
             trimstring(nm, ":");
             LOGDEB("MHExecMultiple: got [" << nm << "] -> [" << data << "]\n");
-            auto it = m_metaData.find(nm);
-            if (it == m_metaData.end() ||
-                it->second.find(data) == std::string::npos) {
-                m_metaData[nm] += data;
-            }
+            addmeta(m_metaData, nm, data);
         }
         if (loop == 200) {
             // ?? 
@@ -317,6 +314,15 @@ bool MimeHandlerExecMultiple::next_document()
                     mtype = "application/octet-stream";
                 }
             }
+            /* If we identify text/plain from the suffix (as opposed
+               to the handler setting the type), we use text/plain1
+               instead. As directed in mimeconf, this will cause the
+               text handler to be applied (instead of internfile just
+               ending things there), allowing splitting and default
+               charset conversions. */
+            if (mtype == "text/plain") {
+                mtype = "text/plain1";
+            }
         }
         m_metaData[cstr_dj_keymt] = mtype;
         if (!m_forPreview) {
