@@ -39,10 +39,9 @@ class AdvSearch : public QDialog, public Ui::AdvSearchBase
 
 public:
     AdvSearch(QDialog* parent = 0) 
-    : QDialog(parent)
-    {
-    setupUi(this);
-    init();
+        : QDialog(parent) {
+        setupUi(this);
+        init();
     }
 
 public slots:
