@@ -219,7 +219,7 @@ void ConfIndexW::initPanels()
         new ConfSubPanelW(m_w, &m_conf, m_rclconf),
         tr("Local parameters"));
 
-    idx = m_w->addPanel("Web history");
+    idx = m_w->addPanel(tr("Web history"));
     setupWebHistoryPanel(idx);
 
     idx = m_w->addPanel(tr("Search parameters"));
@@ -267,6 +267,13 @@ bool ConfIndexW::setupTopPanel(int idx)
         tr("This value adjusts the amount of messages,<br>from only "
            "errors to a lot of debugging data."), 0, 6);
 
+    m_w->addParam(idx, ConfTabsW::CFPT_FN, "idxlogfilename",
+                  tr("Indexer log file name"),
+                  tr("If empty, the above log file name value will be used. "
+                     "It may useful to have a separate log for diagnostic "
+                     "purposes because the common log will be erased when<br>"
+                     "the GUI starts up."), 0);
+    
     m_w->addParam(idx, ConfTabsW::CFPT_INT, "idxflushmb",
                   tr("Index flush megabytes interval"),
                   tr("This value adjust the amount of "
@@ -275,8 +282,8 @@ bool ConfIndexW::setupTopPanel(int idx)
                      "Default 10MB "), 0, 1000);
 
     m_w->addParam(idx, ConfTabsW::CFPT_INT, "maxfsoccuppc",
-                  tr("Disk full threshold to stop indexing<br>"
-                     "(e.g. 90%, 0 means no limit)"),
+                  tr("Disk full threshold percentage at which we stop indexing<br>"
+                     "E.g. 90% to stop at 90% full, 0 or 100 means no limit)"),
                   tr("This is the percentage of disk usage "
                      "- total disk usage, not index size - at which "
                      "indexing will fail and stop.<br>"
