@@ -102,8 +102,6 @@ void rwSettings(bool writing)
     SETTING_RW(prefs.showmode, "/Recoll/geometry/showmode", Int, 0);
     SETTING_RW(prefs.pvwidth, "/Recoll/geometry/pvwidth", Int, 0);
     SETTING_RW(prefs.pvheight, "/Recoll/geometry/pvheight", Int, 0);
-    SETTING_RW(prefs.toolArea, "/Recoll/geometry/toolArea", Int, 0);
-    SETTING_RW(prefs.resArea, "/Recoll/geometry/resArea", Int, 0);
     SETTING_RW(prefs.ssearchTypSav, "/Recoll/prefs/ssearchTypSav", Bool, 0);
     SETTING_RW(prefs.ssearchTyp, "/Recoll/prefs/simpleSearchTyp", Int, 3);
     SETTING_RW(prefs.startWithAdvSearchOpen, 
@@ -220,6 +218,7 @@ void rwSettings(bool writing)
 
     SETTING_RW(prefs.reslistheadertext, "/Recoll/prefs/reslist/headertext", 
                String, "");
+    SETTING_RW(prefs.darkMode, "/Recoll/prefs/darkMode", Bool, 0);
     SETTING_RW(prefs.qssFile, "/Recoll/prefs/stylesheet", String, "");
     SETTING_RW(prefs.snipCssFile, "/Recoll/prefs/snippets/cssfile", String, "");
     SETTING_RW(prefs.queryStemLang, "/Recoll/prefs/query/stemLang", String,
@@ -292,44 +291,13 @@ void rwSettings(bool writing)
             "/Recoll/prefs/query/asearchIgnFilTyps").toStringList();
     }
 
-    // Field list for the restable
-    if (writing) {
-        settings.setValue("/Recoll/prefs/query/restableFields",
-                          prefs.restableFields);
-    } else {
-        prefs.restableFields = 
-            settings.value("/Recoll/prefs/query/restableFields").toStringList();
-        if (prefs.restableFields.empty()) {
-            prefs.restableFields.push_back("date");
-            prefs.restableFields.push_back("title");
-            prefs.restableFields.push_back("filename");
-            prefs.restableFields.push_back("author");
-            prefs.restableFields.push_back("url");
-        }
-    }
-
-    // restable col widths
-    QString rtcw;
-    if (writing) {
-        for (const auto& width : prefs.restableColWidths) {
-            char buf[20];
-            sprintf(buf, "%d ", width);
-            rtcw += QString::fromUtf8(buf);
-        }
-    }
-    SETTING_RW(rtcw, "/Recoll/prefs/query/restableWidths", String, 
-               "83 253 132 172 130 ");
-    if (!writing) {
-        prefs.restableColWidths.clear();
-        vector<string> widths;
-        stringToStrings(qs2utf8s(rtcw), widths);
-        for (const auto& width : widths) {
-            prefs.restableColWidths.push_back(atoi(width.c_str()));
-        }
-    }
-
     SETTING_RW(prefs.fileTypesByCats, "/Recoll/prefs/query/asearchFilTypByCat",
                Bool, false);
+    SETTING_RW(prefs.noClearSearch, "/Recoll/prefs/noClearSearch", Bool, false);
+    SETTING_RW(prefs.noToolbars, "/Recoll/prefs/noToolbars", Bool, false);
+    SETTING_RW(prefs.noStatusBar, "/Recoll/prefs/noStatusBar", Bool, false);
+    SETTING_RW(prefs.noMenuBar, "/Recoll/prefs/noMenuBar", Bool, false);
+    SETTING_RW(prefs.noSSTypCMB, "/Recoll/prefs/noSSTypCMB", Bool, false);
     SETTING_RW(prefs.showTrayIcon, "/Recoll/prefs/showTrayIcon", Bool, false);
     SETTING_RW(prefs.closeToTray, "/Recoll/prefs/closeToTray", Bool, false);
     SETTING_RW(prefs.trayMessages, "/Recoll/prefs/trayMessages", Bool, false);
