@@ -37,7 +37,7 @@ using std::vector;
 
 /** Holder for preferences (gets saved to user Qt prefs) */
 class PrefsPack {
- public:
+public:
     // Simple search entry behaviour
     bool ssearchNoComplete;
     bool ssearchStartOnComplete;
@@ -69,10 +69,8 @@ class PrefsPack {
     int showmode{SHOW_NORMAL};
     int pvwidth; // Preview window geom
     int pvheight;
-    int toolArea; // Area for "tools" toolbar
-    int resArea; // Area for "results" toolbar
     bool ssearchTypSav; // Remember last search mode (else always
-            // start with same)
+    // start with same)
     int ssearchTyp{0};
     // Use single app (default: xdg-open), instead of per-mime settings
     bool useDesktopOpen; 
@@ -131,9 +129,8 @@ class PrefsPack {
     QString synFile;
     bool    synFileEnable;
 
-    QStringList restableFields;
-    vector<int> restableColWidths;
-
+    bool darkMode;
+    
     // Remembered term match mode
     int termMatchType{0};
 
@@ -143,6 +140,11 @@ class PrefsPack {
     // Suppress all noises
     bool noBeeps;
     
+    bool noToolbars{false};
+    bool noClearSearch{false};
+    bool noStatusBar{false};
+    bool noMenuBar{false};
+    bool noSSTypCMB{false};
     bool showTrayIcon{false};
     bool closeToTray{false};
     bool trayMessages{false};
