@@ -331,10 +331,15 @@ void RclMain::showExtIdxDialog()
 
 void RclMain::showAboutDialog()
 {
-    string vstring = Rcl::version_string() +
-        string("<br><a href='https://www.recoll.org'>www.recoll.org</a>") +
-        string("<br><a href='https://www.xapian.org'>www.xapian.org</a>");
-    QMessageBox::information(this, tr("About Recoll"), vstring.c_str());
+    QString darkcss;
+    if (prefs.darkMode) {
+        darkcss = readDarkCSS();
+    }
+    QString vstring = QString("<html><head>") + darkcss + "</head><body>" +
+        u8s2qs(Rcl::version_string()) +
+        "<br><a href='https://www.recoll.org'>www.recoll.org</a>" +
+        "<br><a href='https://www.xapian.org'>www.xapian.org</a>";
+    QMessageBox::information(this, tr("About Recoll"), vstring);
 }
 
 void RclMain::showMissingHelpers()
@@ -466,6 +471,8 @@ void RclMain::newDupsW(const Rcl::Doc, const vector<Rcl::Doc> dups)
 
 void RclMain::showSnippets(Rcl::Doc doc)
 {
+    if (!m_source)
+        return;
     if (!m_snippets) {
         m_snippets = new SnippetsW(doc, m_source);
         connect(m_snippets, SIGNAL(startNativeViewer(Rcl::Doc, int, QString)),
