@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 J.F.Dockes
+/* Copyright (C) 2005-2020 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -25,7 +25,6 @@
 #include <qmessagebox.h>
 #include <qfiledialog.h>
 #include <qshortcut.h>
-#include <qtabwidget.h>
 #include <qtimer.h>
 #include <qstatusbar.h>
 #include <qwindowdefs.h>
@@ -68,12 +67,12 @@
 #include "systray.h"
 #include "rclmain_w.h"
 #include "rclhelp.h"
+#include "readfile.h"
 #include "moc_rclmain_w.cpp"
 
-using std::pair;
-
 QString g_stringAllStem, g_stringNoStem;
-
+static const char *settingskey_toolarea="/Recoll/geometry/toolArea";
+static const char *settingskey_resarea="/Recoll/geometry/resArea";
 static Qt::ToolBarArea int2area(int in)
 {
     switch (in) {
@@ -122,17 +121,9 @@ static QString configToTitle()
 
 void RclMain::init()
 {
-    // This is just to get the common catg strings into the message file
-    static const char* catg_strings[] = {
-        QT_TR_NOOP("All"), QT_TR_NOOP("media"),  QT_TR_NOOP("message"),
-        QT_TR_NOOP("other"),  QT_TR_NOOP("presentation"),
-        QT_TR_NOOP("spreadsheet"),  QT_TR_NOOP("text"), 
-        QT_TR_NOOP("sorted"), QT_TR_NOOP("filtered")
-    };
     setWindowTitle(configToTitle());
 
-    DocSequence::set_translations((const char *)tr("sorted").toUtf8(), 
-                                  (const char *)tr("filtered").toUtf8());
+    buildMenus();
 
     // A shortcut to get the focus back to the search entry, in table
     // mode only.
@@ -149,9 +140,9 @@ void RclMain::init()
     qf.setPermissions(QFile::ReadOwner|QFile::WriteOwner);
     qf.close();
     m_watcher.addPath(idxfn);
-    // At least some versions of qt4 don't display the status bar if
-    // it's not created here.
-    (void)statusBar();
+
+    setupStatusBar();
+    setupMenus();
 
     (void)new HelpClient(this);
     HelpClient::installMap((const char *)this->objectName().toUtf8(),
@@ -162,121 +153,12 @@ void RclMain::init()
 
     enbSynAction->setDisabled(prefs.synFile.isEmpty());
     enbSynAction->setChecked(prefs.synFileEnable);
+    enbDarkModeAction->setChecked(prefs.darkMode);
     
-    // Stemming language menu
-    g_stringNoStem = tr("(no stemming)");
-    g_stringAllStem = tr("(all languages)");
-    m_idNoStem = preferencesMenu->addAction(g_stringNoStem);
-    m_idNoStem->setCheckable(true);
-    m_stemLangToId[g_stringNoStem] = m_idNoStem;
-    m_idAllStem = preferencesMenu->addAction(g_stringAllStem);
-    m_idAllStem->setCheckable(true);
-    m_stemLangToId[g_stringAllStem] = m_idAllStem;
+    setupToolbars();
 
-    // Can't get the stemming languages from the db at this stage as
-    // db not open yet (the case where it does not even exist makes
-    // things complicated). So get the languages from the config
-    // instead
-    vector<string> langs;
-    if (!getStemLangs(langs)) {
-        QMessageBox::warning(0, "Recoll", 
-                             tr("error retrieving stemming languages"));
-    }
-    QAction *curid = prefs.queryStemLang == "ALL" ? m_idAllStem : m_idNoStem;
-    QAction *id; 
-    for (vector<string>::const_iterator it = langs.begin(); 
-         it != langs.end(); it++) {
-        QString qlang = QString::fromUtf8(it->c_str(), it->length());
-        id = preferencesMenu->addAction(qlang);
-        id->setCheckable(true);
-        m_stemLangToId[qlang] = id;
-        if (prefs.queryStemLang == qlang) {
-            curid = id;
-        }
-    }
-    curid->setChecked(true);
-
-    m_toolsTB = new QToolBar(tr("Tools"), this);
-    m_toolsTB->setObjectName(QString::fromUtf8("m_toolsTB"));
-    m_toolsTB->addAction(toolsAdvanced_SearchAction);
-    m_toolsTB->addAction(toolsDoc_HistoryAction);
-    m_toolsTB->addAction(toolsSpellAction);
-    m_toolsTB->addAction(actionQuery_Fragments);
-    this->addToolBar(int2area(prefs.toolArea), m_toolsTB);
-
-    m_resTB = new QToolBar(tr("Results"), this);
-    m_resTB->setObjectName(QString::fromUtf8("m_resTB"));
-    this->addToolBar(int2area(prefs.resArea), m_resTB);
-
-    // Document filter buttons and combobox
-    // Combobox version of the document filter control
-    m_filtCMB = new QComboBox(m_resTB);
-    m_filtCMB->setEditable(false);
-    m_filtCMB->addItem(tr("All"));
-    m_filtCMB->setToolTip(tr("Document filter"));
-    // Buttons version of the document filter control
-    m_filtFRM = new QFrame(this);
-    m_filtFRM->setObjectName(QString::fromUtf8("m_filtFRM"));
-    QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Maximum);
-    sizePolicy2.setHorizontalStretch(0);
-    sizePolicy2.setVerticalStretch(0);
-    sizePolicy2.setHeightForWidth(m_filtFRM->sizePolicy().hasHeightForWidth());
-    m_filtFRM->setSizePolicy(sizePolicy2);
-    QHBoxLayout *bgrphbox = new QHBoxLayout(m_filtFRM);
-    m_filtBGRP  = new QButtonGroup(m_filtFRM);
-    QRadioButton *allRDB = new QRadioButton(m_filtFRM);
-    verticalLayout->insertWidget(1, m_filtFRM);
-    allRDB->setObjectName(QString::fromUtf8("allRDB"));
-    allRDB->setGeometry(QRect(0, 0, 45, 20));
-    allRDB->setText(tr("All"));
-    bgrphbox->addWidget(allRDB);
-    int bgrpid = 0;
-    m_filtBGRP->addButton(allRDB, bgrpid++);
-    allRDB->setChecked(true);
-
-    // Menu version of the document filter control
-    m_filtMN = new QMenu(MenuBar);
-    m_filtMN->setObjectName("m_filtMN");
-    MenuBar->insertMenu(helpMenu->menuAction(), m_filtMN);
-    m_filtMN->setTitle(tr("F&ilter"));
-    QActionGroup *fltag = new QActionGroup(this);
-    fltag->setExclusive(true);
-    QAction *act = fltag->addAction(tr("All"));
-    m_filtMN->addAction(act);
-    act->setCheckable(true);
-    act->setData((int)0);
-
-    // Go through the filter list and setup buttons and combobox
-    vector<string> cats;
-    theconfig->getGuiFilterNames(cats);
-    m_catgbutvec.push_back(catg_strings[0]);
-    for (vector<string>::const_iterator it = cats.begin();
-         it != cats.end(); it++) {
-        QRadioButton *but = new QRadioButton(m_filtFRM);
-        QString catgnm = QString::fromUtf8(it->c_str(), it->length());
-        m_catgbutvec.push_back(*it);
-        // We strip text before the first colon before setting the button name.
-        // This is so that the user can decide the order of buttons by naming 
-        // the filter,ie, a:media b:messages etc.
-        QString but_txt = catgnm;
-        int colon = catgnm.indexOf(':');
-        if (colon != -1) {
-            but_txt = catgnm.right(catgnm.size()-(colon+1));
-        }
-        but->setText(tr(but_txt.toUtf8()));
-        m_filtCMB->addItem(tr(but_txt.toUtf8()));
-        bgrphbox->addWidget(but);
-        m_filtBGRP->addButton(but, bgrpid++);
-        QAction *act = fltag->addAction(tr(but_txt.toUtf8()));
-        m_filtMN->addAction(act);
-        act->setCheckable(true);
-        act->setData((int)(m_catgbutvec.size()-1));
-        m_filtMN->connect(m_filtMN, SIGNAL(triggered(QAction *)), this, 
-                          SLOT(catgFilter(QAction *)));
-    }
-    m_filtFRM->setLayout(bgrphbox);
-    connect(m_filtBGRP, SIGNAL(buttonClicked(int)),this, SLOT(catgFilter(int)));
-    connect(m_filtCMB, SIGNAL(activated(int)), this, SLOT(catgFilter(int)));
+    //////// 3 versions of results category filtering: buttons, combobox, menu
+    setupCategoryFiltering();
 
     restable = new ResTable(this);
     verticalLayout->insertWidget(2, restable);
@@ -358,6 +240,8 @@ void RclMain::init()
             this, SLOT(showExtIdxDialog()));
     connect(enbSynAction, SIGNAL(toggled(bool)),
             this, SLOT(setSynEnabled(bool)));
+    connect(enbDarkModeAction, SIGNAL(toggled(bool)),
+            this, SLOT(setDarkModeEnabled(bool)));
 
     connect(toggleFullScreenAction, SIGNAL(triggered()), 
             this, SLOT(toggleFullScreen()));
@@ -377,6 +261,8 @@ void RclMain::init()
             restable, SLOT(readDocSource()));
     connect(this, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
             restable, SLOT(onSortDataChanged(DocSeqSortSpec)));
+    connect(this, SIGNAL(sortDataChanged(DocSeqSortSpec)), 
+            this, SLOT(onSortDataChanged(DocSeqSortSpec)));
     connect(this, SIGNAL(uiPrefsChanged()), restable, SLOT(onUiPrefsChanged()));
 
     connect(restable->getModel(), SIGNAL(sortDataChanged(DocSeqSortSpec)),
@@ -439,7 +325,6 @@ void RclMain::init()
     if (prefs.keepSort && prefs.sortActive) {
         m_sortspec.field = (const char *)prefs.sortField.toUtf8();
         m_sortspec.desc = prefs.sortDesc;
-        onSortDataChanged(m_sortspec);
         emit sortDataChanged(m_sortspec);
     }
     QSettings settings;
@@ -455,6 +340,64 @@ void RclMain::init()
     periodictimer->start(1000);
 }
 
+void RclMain::setupToolbars()
+{
+    if (nullptr == m_toolsTB) {
+        m_toolsTB = new QToolBar(tr("Tools"), this);
+        m_toolsTB->setObjectName(QString::fromUtf8("m_toolsTB"));
+        m_toolsTB->addAction(toolsAdvanced_SearchAction);
+        m_toolsTB->addAction(toolsDoc_HistoryAction);
+        m_toolsTB->addAction(toolsSpellAction);
+        m_toolsTB->addAction(actionQuery_Fragments);
+    }
+    QSettings settings;
+    int val;
+    if (!prefs.noToolbars) {
+        val = settings.value(settingskey_toolarea).toInt();
+        this->addToolBar(int2area(val), m_toolsTB);
+        m_toolsTB->show();
+    } else {
+        m_toolsTB->hide();
+    }
+    if (nullptr == m_resTB) {
+        m_resTB = new QToolBar(tr("Results"), this);
+        m_resTB->setObjectName(QString::fromUtf8("m_resTB"));
+    }
+    if (!prefs.noToolbars) {
+        val = settings.value(settingskey_resarea).toInt();
+        this->addToolBar(int2area(val), m_resTB);
+        m_resTB->show();
+    } else {
+        m_resTB->hide();
+    }
+}
+
+void RclMain::setupStatusBar()
+{
+    auto bar = statusBar();
+    if (prefs.noStatusBar) {
+        bar->hide();
+    } else {
+        bar->show();
+    }
+}
+
+void RclMain::setupMenus()
+{
+    if (prefs.noMenuBar) {
+        MenuBar->hide();
+        sSearch->menuPB->show();
+        butmenuSC = new QShortcut(QKeySequence("Alt+m"), this);
+        connect(butmenuSC, SIGNAL(activated()),
+                sSearch->menuPB, SLOT(showMenu()));
+    } else {
+        MenuBar->show();
+        sSearch->menuPB->hide();
+        deleteZ(butmenuSC);
+    }
+}
+
+
 void RclMain::enableTrayIcon(bool on)
 {
     on =  on && QSystemTrayIcon::isSystemTrayAvailable();
@@ -469,6 +412,86 @@ void RclMain::enableTrayIcon(bool on)
     }
 }
 
+void RclMain::setupCategoryFiltering()
+{
+    // This is just to get the common catg strings into the message file
+    static const char* catg_strings[] = {
+        QT_TR_NOOP("All"), QT_TR_NOOP("media"),  QT_TR_NOOP("message"),
+        QT_TR_NOOP("other"),  QT_TR_NOOP("presentation"),
+        QT_TR_NOOP("spreadsheet"),  QT_TR_NOOP("text"), 
+        QT_TR_NOOP("sorted"), QT_TR_NOOP("filtered")
+    };
+
+    //// Combobox version 
+    m_filtCMB = new QComboBox(m_resTB);
+    m_filtCMB->setEditable(false);
+    m_filtCMB->addItem(tr("All"));
+    m_filtCMB->setToolTip(tr("Document filter"));
+
+    //// Buttons version
+    m_filtFRM = new QFrame(this);
+    m_filtFRM->setObjectName(QString::fromUtf8("m_filtFRM"));
+    QHBoxLayout *bgrphbox = new QHBoxLayout(m_filtFRM);
+    verticalLayout->insertWidget(1, m_filtFRM);
+    QSizePolicy sizePolicy2(QSizePolicy::Preferred, QSizePolicy::Maximum);
+    sizePolicy2.setHorizontalStretch(0);
+    sizePolicy2.setVerticalStretch(0);
+    sizePolicy2.setHeightForWidth(m_filtFRM->sizePolicy().hasHeightForWidth());
+    m_filtFRM->setSizePolicy(sizePolicy2);
+    m_filtBGRP  = new QButtonGroup(m_filtFRM);
+    QRadioButton *allRDB = new QRadioButton(m_filtFRM);
+    allRDB->setObjectName("allRDB");
+    allRDB->setText(tr("All"));
+    bgrphbox->addWidget(allRDB);
+    int bgrpid = 0;
+    m_filtBGRP->addButton(allRDB, bgrpid++);
+    allRDB->setChecked(true);
+    m_filtFRM->setLayout(bgrphbox);
+
+    //// Menu version of the document filter control
+    m_filtMN = new QMenu(MenuBar);
+    m_filtMN->setObjectName("m_filtMN");
+    MenuBar->insertMenu(viewMenu->menuAction(), m_filtMN);
+    buttonTopMenu->insertMenu(viewMenu->menuAction(), m_filtMN);
+    m_filtMN->setTitle(tr("F&ilter"));
+    QActionGroup *fltag = new QActionGroup(this);
+    fltag->setExclusive(true);
+    QAction *act = fltag->addAction(tr("All"));
+    m_filtMN->addAction(act);
+    act->setCheckable(true);
+    act->setData((int)0);
+
+    //// Go through the categories list and setup menu, buttons and combobox
+    vector<string> cats;
+    theconfig->getGuiFilterNames(cats);
+    m_catgbutvec.push_back(catg_strings[0]);
+    for (const auto& cat : cats) {
+        QRadioButton *but = new QRadioButton(m_filtFRM);
+        QString catgnm = u8s2qs(cat);
+        m_catgbutvec.push_back(cat);
+        // We strip text before the first colon before setting the button name.
+        // This is so that the user can decide the order of buttons by naming 
+        // the filter,ie, a:media b:messages etc.
+        QString but_txt = catgnm;
+        int colon = catgnm.indexOf(':');
+        if (colon != -1) {
+            but_txt = catgnm.right(catgnm.size()-(colon+1));
+        }
+        but->setText(tr(but_txt.toUtf8()));
+        m_filtCMB->addItem(tr(but_txt.toUtf8()));
+        bgrphbox->addWidget(but);
+        m_filtBGRP->addButton(but, bgrpid++);
+        QAction *act = fltag->addAction(tr(but_txt.toUtf8()));
+        m_filtMN->addAction(act);
+        act->setCheckable(true);
+        act->setData((int)(m_catgbutvec.size()-1));
+        m_filtMN->connect(m_filtMN, SIGNAL(triggered(QAction *)), this, 
+                          SLOT(catgFilter(QAction *)));
+    }
+    connect(m_filtBGRP, SIGNAL(buttonClicked(int)),this, SLOT(catgFilter(int)));
+    connect(m_filtCMB, SIGNAL(activated(int)), this, SLOT(catgFilter(int)));
+}
+
 void RclMain::setSynEnabled(bool on)
 {
     prefs.synFileEnable = on;
@@ -476,6 +499,72 @@ void RclMain::setSynEnabled(bool on)
         uiprefs->synFileCB->setChecked(prefs.synFileEnable);
 }
 
+QString RclMain::readDarkCSS()
+{
+    if (nullptr == theconfig) {
+        return QString();
+    }
+    string fn = path_cat(
+        path_cat(theconfig->getDatadir(), "examples"), "recoll-dark.css");
+    string data;
+    string reason;
+    if (!file_to_string(fn, data, &reason)) {
+        QMessageBox::warning(0, "Recoll", tr("Could not read: ") + u8s2qs(fn));
+        return QString();
+    }
+    return u8s2qs(data);
+}
+
+void RclMain::setDarkModeEnabled(bool on)
+{
+    string fn;
+    
+    if (on) {
+        if (!prefs.reslistheadertext.isEmpty() || !prefs.qssFile.isEmpty()) {
+            QString message =
+                tr("This will replace the current contents of the result list"
+                   " header string and GUI qss file name. Continue ?");
+            switch(QMessageBox::warning(0, "Recoll", message, 
+                                        "Yes", "No", 0, 0, 1)) {
+            case 0: 
+                break;
+            case 1:
+                goto resetcheckednosigs;
+            }
+        }
+        string datadir = theconfig->getDatadir();
+        fn = path_cat(path_cat(datadir, "examples"), "recoll-dark.qss");
+        if (!path_readable(fn)) {
+            goto unreadable;
+        }
+        prefs.qssFile = u8s2qs(fn);
+
+        prefs.reslistheadertext = readDarkCSS();
+    } else {
+        prefs.reslistheadertext.clear();
+        prefs.qssFile.clear();
+    }
+
+    applyStyleSheet();
+    prefs.darkMode = on;
+    if (uiprefs) {
+        uiprefs->resetStylesheet(prefs.qssFile);
+    }
+    QMessageBox::warning(0, "Recoll", tr("You will need to run a query to "
+                                         "complete the display change."));
+    return;
+
+unreadable:
+    QMessageBox::warning(0, "Recoll", tr("Could not read: ") + u8s2qs(fn));
+    prefs.reslistheadertext.clear();
+    prefs.qssFile.clear();
+    // And reset checkbox state:
+resetcheckednosigs:
+    bool oldState = enbDarkModeAction->blockSignals(true);
+    enbDarkModeAction->setChecked(!on);
+    enbDarkModeAction->blockSignals(oldState);
+}
+
 void RclMain::resultCount(int n)
 {
     actionSortByDateAsc->setEnabled(n>0);
@@ -546,8 +635,9 @@ void RclMain::initDbOpen()
             // Don't open adv search or run cmd line search in this case.
             return;
         } else {
-            QMessageBox::warning(0, "Recoll", 
-                                 tr("Could not open external index. Db not open. Check external indexes list."));
+            QMessageBox::warning(0, "Recoll",
+                                 tr("Could not open external index. Db not "
+                                    "open. Check external indexes list."));
         }
     }
 
@@ -568,18 +658,16 @@ void RclMain::setStemLang(QAction *id)
     // Check that the menu entry is for a stemming language change
     // (might also be "show prefs" etc.
     bool isLangId = false;
-    for (map<QString, QAction*>::const_iterator it = m_stemLangToId.begin();
-         it != m_stemLangToId.end(); it++) {
-        if (id == it->second)
+    for (const auto& entry : m_stemLangToId) {
+        if (id == entry.second)
             isLangId = true;
     }
     if (!isLangId)
         return;
 
     // Set the "checked" item state for lang entries
-    for (map<QString, QAction*>::const_iterator it = m_stemLangToId.begin();
-         it != m_stemLangToId.end(); it++) {
-        (it->second)->setChecked(false);
+    for (auto& entry : m_stemLangToId) {
+        entry.second->setChecked(false);
     }
     id->setChecked(true);
 
@@ -610,14 +698,13 @@ void RclMain::setStemLang(const QString& lang)
     } else if (lang == "ALL") {
         id = m_idAllStem;
     } else {
-        map<QString, QAction*>::iterator it = m_stemLangToId.find(lang);
+        auto it = m_stemLangToId.find(lang);
         if (it == m_stemLangToId.end()) 
             return;
         id = it->second;
     }
-    for (map<QString, QAction*>::const_iterator it = m_stemLangToId.begin();
-         it != m_stemLangToId.end(); it++) {
-        (it->second)->setChecked(false);
+    for (const auto& entry : m_stemLangToId) {
+        entry.second->setChecked(false);
     }
     id->setChecked(true);
 }
@@ -671,13 +758,14 @@ void RclMain::fileExit()
 
     // Don't save geometry if we're currently maximized. At least under X11
     // this saves the maximized size. otoh isFullscreen() does not seem needed
+    QSettings settings;
     if (!isMaximized()) {
-        QSettings settings;
         settings.setValue("/Recoll/geometry/maingeom", saveGeometry());
     }
-    
-    prefs.toolArea = toolBarArea(m_toolsTB);
-    prefs.resArea = toolBarArea(m_resTB);
+    if (!prefs.noToolbars) {
+        settings.setValue(settingskey_toolarea, toolBarArea(m_toolsTB));
+        settings.setValue(settingskey_resarea, toolBarArea(m_resTB));
+    }
     restable->saveColState();
 
     if (prefs.ssearchTypSav) {
@@ -731,10 +819,18 @@ void RclMain::startSearch(std::shared_ptr<Rcl::SearchData> sdata, bool issimple)
     curPreview = 0;
     DocSequenceDb *src = 
         new DocSequenceDb(rcldb, std::shared_ptr<Rcl::Query>(query), 
-                          string(tr("Query results").toUtf8()), sdata);
+                          qs2utf8s(tr("Query results")), sdata);
     src->setAbstractParams(prefs.queryBuildAbstract, 
                            prefs.queryReplaceAbstract);
     m_source = std::shared_ptr<DocSequence>(src);
+
+    // If this is a file name search sort by mtype so that directories
+    // come first (see the rclquery sort key generator)
+    if (sSearch->searchTypCMB->currentIndex() == SSearch::SST_FNM &&
+        m_sortspec.field.empty()) {
+        m_sortspec.field = "mtype";
+        m_sortspec.desc = false;
+    }
     m_source->setSortSpec(m_sortspec);
     m_source->setFiltSpec(m_filtspec);
 
@@ -840,6 +936,12 @@ void RclMain::onSortCtlChanged()
     } else {
         prefs.sortActive = prefs.sortDesc = false;
         prefs.sortField = "";
+        // If this is a file name search sort by mtype so that directories
+        // come first (see the rclquery sort key generator)
+        if (sSearch->searchTypCMB->currentIndex() == SSearch::SST_FNM) {
+            m_sortspec.field = "mtype";
+            m_sortspec.desc = false;
+        }
     }
     if (m_source)
         m_source->setSortSpec(m_sortspec);
@@ -867,6 +969,14 @@ void RclMain::onSortDataChanged(DocSeqSortSpec spec)
     prefs.sortDesc = spec.desc;
     prefs.sortActive = !spec.field.empty();
 
+    std::string fld;
+    if (!m_sortspec.field.empty()) {
+        fld = qs2utf8s(RecollModel::displayableField(m_sortspec.field));
+    }
+    DocSequence::set_translations(
+        qs2utf8s(tr("sorted")) + ": " + fld +
+        (m_sortspec.desc?" &darr;":" &uarr;"),
+        qs2utf8s(tr("filtered")));
     initiateQuery();
 }
 
@@ -1068,8 +1178,8 @@ void RclMain::exportSimpleSearchHistory()
     }
     string path = qs2utf8s(dialog.selectedFiles().value(0));
     LOGDEB("Chosen path: " << path << "\n");
-    std::fstream fp = path_open(path, std::ios::out | std::ios::trunc);
-    if (!fp.is_open()) {
+    std::fstream fp;
+    if (!path_streamopen(path, std::ios::out | std::ios::trunc, fp)) {
         QMessageBox::warning(0, "Recoll", tr("Could not open/create file"));
         return;
     }
