@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2005-2020 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -18,8 +18,8 @@
 #define RCLMAIN_W_H
 #include "autoconfig.h"
 
-#include <qvariant.h>
-#include <qmainwindow.h>
+#include <QVariant>
+#include <QMainWindow>
 #include <QFileSystemWatcher>
 
 #include "sortseq.h"
@@ -49,6 +49,7 @@ class WebcacheEdit;
 class ConfIndexW;
 class RclTrayIcon;
 class QShortcut;
+class QActionGroup;
 
 #include "ui_rclmain.h"
 
@@ -88,7 +89,13 @@ public:
         return m_indexerState;
     }
     void enableTrayIcon(bool onoff);
-                            
+    QString readDarkCSS();
+    void setupToolbars();
+    void setupStatusBar();
+    void buildMenus();
+    void setupMenus();
+    void setupCategoryFiltering();
+                                 
 public slots:
     virtual void fileExit();
     virtual void periodic100();
@@ -113,6 +120,7 @@ public slots:
     virtual void showDocHistory();
     virtual void showExtIdxDialog();
     virtual void setSynEnabled(bool);
+    virtual void setDarkModeEnabled(bool);
     virtual void showUIPrefs();
     virtual void showIndexConfig();
     virtual void execIndexConfig();
@@ -163,6 +171,9 @@ public slots:
 private slots:
     virtual void updateIdxStatus();
     virtual void onWebcacheDestroyed(QObject *);
+    virtual void onSSTypMenu(QAction *act);
+    virtual void onSSTypCMB(int);
+
 signals:
     void docSourceChanged(std::shared_ptr<DocSequence>);
     void stemLangChanged(const QString& lang);
@@ -233,6 +244,19 @@ private:
     RclTrayIcon     *m_trayicon{0};
     // We sometimes take the indexer lock (e.g.: when editing the webcache)
     Pidfile         *m_pidfile{0};
+
+    // Menu for the button version of the top menu.
+    QMenu *buttonTopMenu;
+    // Entries/submenus for the top menu.
+    QMenu *fileMenu;
+    QMenu *viewMenu;
+    QMenu *toolsMenu;
+    QMenu *preferencesMenu;
+    QMenu *helpMenu;
+    QMenu *resultsMenu;
+    QActionGroup *sstypGroup;
+    QMenu *queryMenu;
+    QShortcut *butmenuSC{nullptr};
     
     virtual void init();
     virtual void setupResTB(bool combo);
