@@ -1,4 +1,4 @@
-/* Copyright (C) 2005 J.F.Dockes
+/* Copyright (C) 2005-2020 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -66,9 +66,11 @@ static const QKeySequence closeKeySeq("Ctrl+w");
 # include <QWebSettings>
 # define QWEBSETTINGS QWebSettings
 #elif defined(USING_WEBENGINE)
-// Notes for WebEngine
-// - All links must begin with http:// for acceptNavigationRequest to be
-//   called. 
+// Notes for WebEngine:
+// - It used to be that all links must begin with http:// for
+//   acceptNavigationRequest to be called. Can't remember if file://
+//   would work. Anyway not any more since we set baseURL. See comments
+//   in linkClicked().
 // - The links passed to acceptNav.. have the host part 
 //   lowercased -> we change S0 to http://localhost/S0, not http://S0
 # include <QWebEnginePage>
@@ -143,12 +145,23 @@ public:
     virtual void suggest(const vector<string>uterms, 
                          map<string, vector<string> >& sugg);
     virtual string absSep() {return (const char *)(prefs.abssep.toUtf8());}
-#ifdef USING_WEBENGINE
-    virtual string linkPrefix() override {return "http://localhost/";}
+
+#if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
+    // We used to use http://localhost/. Now use file:/// as this is
+    // what Webengine will prepend relative links with (as
+    // baseURL). This is for the case where a user adds a link like
+    // P%N, which would not work if linkPrefix and baseURL were not
+    // the same.
+    //
+    // Now also set for webkit because, as we set baseURL to file://,
+    // the relative links we set in the list will also be prefixed (by
+    // the HTML engine)
+    virtual string linkPrefix() override {return "file:///";}
     virtual string bodyAttrs() override {
         return "onload=\"addEventListener('contextmenu', saveLoc)\"";
     }
 #endif
+
 private:
     ResList *m_reslist;
 };
@@ -165,8 +178,6 @@ bool QtGuiResListPager::append(const string& data)
 bool QtGuiResListPager::append(const string& data, int docnum, 
                                const Rcl::Doc&)
 {
-    LOGDEB2("QtGuiReslistPager::appendDoc: blockCount " <<
-            m_reslist->document()->blockCount() << ", " << data << "\n");
 #if defined(USING_WEBKIT) || defined(USING_WEBENGINE)
     QString sdoc = QString(
         "<div class=\"rclresult\" id=\"%1\" rcldocnum=\"%1\">").arg(docnum);
@@ -357,6 +368,7 @@ ResList::ResList(QWidget* parent, const char* name)
 
     m_pager = new QtGuiResListPager(this, prefs.respagesize, prefs.alwaysSnippets);
     m_pager->setHighLighter(&g_hiliter);
+    resetView();
 }
 
 ResList::~ResList()
@@ -496,7 +508,10 @@ void ResList::resetView()
     // blank. Else, there are often icons or text left around
 #if defined(USING_WEBKIT) || defined(USING_WEBENGINE)
     m_text = "";
-    setHtml("<html><body></body></html>");
+    QString html("<html><head>");
+    html += u8s2qs(m_pager->headerContent()) + "</head>";
+    html += "<body></body></html>";
+    setHtml(html);
 #else
     m_pageParaToReldocnums.clear();
     clear();
@@ -545,19 +560,18 @@ pair<int,int> ResList::parnumfromdocnum(int docnum)
     LOGDEB("parnumfromdocnum: docnum " << docnum << "\n");
     if (m_pager->pageNumber() < 0) {
         LOGDEB("parnumfromdocnum: no page return -1,-1\n");
-        return pair<int,int>(-1,-1);
+        return {-1, -1};
     }
     int winfirst = pageFirstDocNum();
     if (docnum - winfirst < 0) {
         LOGDEB("parnumfromdocnum: docnum " << docnum << " < winfirst " <<
                winfirst << " return -1,-1\n");
-        return pair<int,int>(-1,-1);
+        return {-1, -1};
     }
     docnum -= winfirst;
-    for (std::map<int,int>::iterator it = m_pageParaToReldocnums.begin();
-         it != m_pageParaToReldocnums.end(); it++) {
-        if (docnum == it->second) {
-            int first = it->first;
+    for (const auto& entry : m_pageParaToReldocnums) {
+        if (docnum == entry.second) {
+            int first = entry.first;
             int last = first+1;
             std::map<int,int>::iterator it1;
             while ((it1 = m_pageParaToReldocnums.find(last)) != 
@@ -565,11 +579,11 @@ pair<int,int> ResList::parnumfromdocnum(int docnum)
                 last++;
             }
             LOGDEB("parnumfromdocnum: return " << first << "," << last << "\n");
-            return pair<int,int>(first, last);
+            return {first, last};
         }
     }
     LOGDEB("parnumfromdocnum: not found return -1,-1\n");
-    return pair<int,int>(-1,-1);
+    return {-1,-1};
 }
 #endif // TEXTBROWSER
 
@@ -812,7 +826,10 @@ void ResList::displayPage()
     m_pager->displayPage(theconfig);
 
 #if defined(USING_WEBENGINE) || defined(USING_WEBKIT)
-    setHtml(m_text);
+    // webengine from qt 5.15 on won't load local images if the base URL is
+    // not set (previous versions worked with an empty one). Can't hurt anyway.
+    const static QUrl baseUrl("file:///");
+    setHtml(m_text, baseUrl);
 #endif
 
     LOGDEB0("ResList::displayPg: hasNext " << m_pager->hasNext() <<
@@ -940,25 +957,52 @@ void ResList::onLinkClicked(const QUrl &qurl)
     // want. e.g. Suggestions links are like Sterm|spelling which we
     // receive as Sterm%7CSpelling
     string strurl = url_decode(qs2utf8s(qurl.toString()));
-    
+
+    // Link prefix remark: it used to be that webengine refused to
+    // acknowledge link clicks on links like "%P1", it needed an
+    // absolute URL like http://localhost/P1. This does not seem to be
+    // the case any more, probably because we now set baseUrl (to fix
+    // icons display which had stopped working). So the linkprefix
+    // thing could probably go away. OTOH, we'd have to substract the
+    // baseUrl because we receive links like baseUrl+P1 instead.
     LOGDEB1("ResList::onLinkClicked: [" << strurl << "] prefix " <<
             m_pager->linkPrefix() << "\n");
+    if (m_pager->linkPrefix().size() > 0 &&
+        (strurl.size() <= m_pager->linkPrefix().size() ||
+         !beginswith(strurl, m_pager->linkPrefix()))) {
+        return;
+    }
     strurl = strurl.substr(m_pager->linkPrefix().size());
 
+    if (strurl.size() == 0) {
+        return;
+    }
+    int docnum{-1};
+    bool havedoc{false};
+    Rcl::Doc doc;
+    if (strurl.size() > 1) {
+        // If an integer follows interpret as doc number
+        const char *bptr = strurl.c_str() + 1;
+        char *eptr;
+        docnum = strtol(bptr, &eptr, 10) - 1;
+        if (docnum >= 0) {
+            if (getDoc(docnum, doc)) {
+                havedoc = true;
+            } else {
+                LOGERR("ResList::onLinkClicked: can't get doc for "<<
+                       docnum << "\n");
+            }
+        }
+    }
+
     int what = strurl[0];
     switch (what) {
 
         // Open abstract/snippets window
     case 'A':
     {
-        if (!m_source) 
+        if (!havedoc)
             return;
-        int i = atoi(strurl.c_str()+1) - 1;
-        Rcl::Doc doc;
-        if (!getDoc(i, doc)) {
-            LOGERR("ResList::onLinkClicked: can't get doc for " << i << "\n");
-            return;
-        }
         emit(showSnippets(doc));
     }
     break;
@@ -966,14 +1010,8 @@ void ResList::onLinkClicked(const QUrl &qurl)
     // Show duplicates
     case 'D':
     {
-        if (!m_source) 
+        if (!m_source || !havedoc) 
             return;
-        int i = atoi(strurl.c_str()+1) - 1;
-        Rcl::Doc doc;
-        if (!getDoc(i, doc)) {
-            LOGERR("ResList::onLinkClicked: can't get doc for " << i << "\n");
-            return;
-        }
         vector<Rcl::Doc> dups;
         if (m_source->docDups(doc, dups) && m_rclmain) {
             m_rclmain->newDupsW(doc, dups);
@@ -984,14 +1022,9 @@ void ResList::onLinkClicked(const QUrl &qurl)
     // Open parent folder
     case 'F':
     {
-        int i = atoi(strurl.c_str()+1) - 1;
-        Rcl::Doc doc;
-        if (!getDoc(i, doc)) {
-            LOGERR("ResList::onLinkClicked: can't get doc for " << i << "\n");
+        if (!havedoc)
             return;
-        }
-        emit editRequested(ResultPopup::getParent(std::shared_ptr<DocSequence>(),
-                                                  doc));
+        emit editRequested(ResultPopup::getFolder(doc));
     }
     break;
 
@@ -1007,15 +1040,11 @@ void ResList::onLinkClicked(const QUrl &qurl)
     case 'P': 
     case 'E': 
     {
-        int i = atoi(strurl.c_str()+1) - 1;
-        Rcl::Doc doc;
-        if (!getDoc(i, doc)) {
-            LOGERR("ResList::onLinkClicked: can't get doc for " << i << "\n");
+        if (!havedoc)
             return;
-        }
         if (what == 'P') {
             if (m_ismainres) {
-                emit docPreviewClicked(i, doc, m_lstClckMod);
+                emit docPreviewClicked(docnum, doc, m_lstClckMod);
             } else {
                 emit previewRequested(doc);
             }
@@ -1036,7 +1065,8 @@ void ResList::onLinkClicked(const QUrl &qurl)
         // Run script. Link format Rnn|Script Name
     case 'R':
     {
-        int i = atoi(strurl.c_str() + 1) - 1;
+        if (!havedoc)
+            return;
         QString s = qurl.toString();
         int bar = s.indexOf("|");
         if (bar == -1 || bar >= s.size()-1)
@@ -1048,7 +1078,7 @@ void ResList::onLinkClicked(const QUrl &qurl)
             QAction act(QString::fromUtf8(app.name.c_str()), this);
             QVariant v(QString::fromUtf8(app.command.c_str()));
             act.setData(v);
-            m_popDoc = i;
+            m_popDoc = docnum;
             menuOpenWith(&act);
         }
     }
@@ -1071,8 +1101,9 @@ void ResList::onLinkClicked(const QUrl &qurl)
     break;
 
     default: 
-        LOGERR("ResList::onLinkClicked: bad link [" << strurl.substr(0,20) << "]\n");
-        break;// ?? 
+        LOGERR("ResList::onLinkClicked: bad link [" << strurl.substr(0,20) <<
+               "]\n");
+        break;
     }
 }
 
@@ -1080,7 +1111,12 @@ void ResList::onPopupJsDone(const QVariant &jr)
 {
     QString qs(jr.toString());
     LOGDEB("onPopupJsDone: parameter: " << qs2utf8s(qs) << "\n");
-    QStringList qsl = qs.split("\n", QString::SkipEmptyParts);
+#if (QT_VERSION >= QT_VERSION_CHECK(5, 15, 0))
+    auto skipflags = Qt::SkipEmptyParts;
+#else
+    auto skipflags = QString::SkipEmptyParts;
+#endif
+    QStringList qsl = qs.split("\n", skipflags);
     for (int i = 0 ; i < qsl.size(); i++) {
         int eq = qsl[i].indexOf("=");
         if (eq > 0) {
@@ -1175,8 +1211,23 @@ void ResList::menuPreviewParent()
 void ResList::menuOpenParent()
 {
     Rcl::Doc doc;
-    if (getDoc(m_popDoc, doc) && m_source) 
-        emit editRequested(ResultPopup::getParent(m_source, doc));
+    if (getDoc(m_popDoc, doc) && m_source)  {
+        Rcl::Doc pdoc = ResultPopup::getParent(m_source, doc);
+        if (!pdoc.url.empty()) {
+            emit editRequested(pdoc);
+        }
+    }
+}
+
+void ResList::menuOpenFolder()
+{
+    Rcl::Doc doc;
+    if (getDoc(m_popDoc, doc) && m_source) {
+        Rcl::Doc pdoc = ResultPopup::getFolder(doc);
+        if (!pdoc.url.empty()) {
+            emit editRequested(pdoc);
+        }
+    }
 }
 
 void ResList::menuShowSnippets()
