@@ -1,4 +1,4 @@
-/*
+/* Copyright (C) 2005-2020 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
  *   the Free Software Foundation; either version 2 of the License, or
@@ -70,6 +70,10 @@ static const int fsadjusttable = 1;
 
 static PlainToRichQtReslist g_hiliter;
 
+static const char *settingskey_fieldlist="/Recoll/prefs/query/restableFields";
+static const char *settingskey_fieldwiths="/Recoll/prefs/query/restableWidths";
+static const char *settingskey_splittersizes="resTableSplitterSizes";
+
 //////////////////////////////////////////////////////////////////////////
 // Restable "pager". We use it to print details for a document in the 
 // detail area
@@ -79,22 +83,28 @@ public:
     ResTablePager(ResTable *p)
         : ResListPager(1, prefs.alwaysSnippets), m_parent(p) 
         {}
-    virtual bool append(const string& data, int idx, const Rcl::Doc& doc);
-    virtual string trans(const string& in);
-    virtual const string &parFormat();
-    virtual string absSep() {return (const char *)(prefs.abssep.toUtf8());}
+    virtual bool append(const string& data) override;
+    virtual bool flush() override;
+    virtual string trans(const string& in) override;
+    virtual const string &parFormat() override;
+    virtual string absSep() override {
+        return (const char *)(prefs.abssep.toUtf8());}
+    virtual string headerContent() override {
+        return qs2utf8s(prefs.reslistheadertext);}
 private:
     ResTable *m_parent;
+    string m_data;
 };
 
-bool ResTablePager::append(const string& data, int, const Rcl::Doc&)
+bool ResTablePager::append(const string& data)
 {
-    m_parent->m_detail->moveCursor(QTextCursor::End, QTextCursor::MoveAnchor);
-    m_parent->m_detail->textCursor().insertBlock();
-    m_parent->m_detail->insertHtml(u8s2qs(data));
-
-//    LOGDEB("RESTABLEPAGER::APPEND: data : " << data << std::endl);
-//    m_parent->m_detail->setHtml(u8s2qs(data));
+    m_data += data;
+    return true;
+}
+bool ResTablePager::flush()
+{
+    m_parent->m_detail->setHtml(u8s2qs(m_data));
+    m_data = "";
     return true;
 }
 
@@ -147,6 +157,12 @@ void ResTableDetailArea::setFont()
     }
 }
 
+void ResTableDetailArea::init()
+{
+    setFont();
+    QTextBrowser::setHtml("");
+}
+
 //////////////////////////////////////////////////////////////////////////////
 //// Data model methods
 ////
@@ -239,7 +255,7 @@ RecollModel::RecollModel(const QStringList fields, ResTable *tb,
     o_displayableFields["relevancyrating"] = tr("Relevancy rating");
     o_displayableFields["title"] = tr("Title");
     o_displayableFields["url"] = tr("URL");
-    o_displayableFields["mtime"] = tr("Mtime");
+    o_displayableFields["mtime"] = tr("Date");
     o_displayableFields["date"] = tr("Date");
     o_displayableFields["datetime"] = tr("Date and time");
 
@@ -247,11 +263,10 @@ RecollModel::RecollModel(const QStringList fields, ResTable *tb,
     // could be protected to be done only once, but it's no real
     // problem
     if (theconfig) {
-        const set<string>& stored = theconfig->getStoredFields();
-        for (set<string>::const_iterator it = stored.begin(); 
-             it != stored.end(); it++) {
-            if (o_displayableFields.find(*it) == o_displayableFields.end()) {
-                o_displayableFields[*it] = QString::fromUtf8(it->c_str());
+        const auto& stored = theconfig->getStoredFields();
+        for (const auto& field : stored) {
+            if (o_displayableFields.find(field) == o_displayableFields.end()) {
+                o_displayableFields[field] = u8s2qs(field);
             }
         }
     }
@@ -290,6 +305,7 @@ void RecollModel::readDocSource()
 void RecollModel::setDocSource(std::shared_ptr<DocSequence> nsource)
 {
     LOGDEB("RecollModel::setDocSource\n");
+    m_rowforcachedoc = -1;
     if (!nsource) {
         m_source = std::shared_ptr<DocSequence>();
     } else {
@@ -330,6 +346,12 @@ void RecollModel::addColumn(int col, const string& field)
     }
 }
 
+QString RecollModel::displayableField(const std::string& in)
+{
+    const auto it = o_displayableFields.find(in);
+    return (it == o_displayableFields.end()) ? u8s2qs(in) : it->second;
+}
+
 QVariant RecollModel::headerData(int idx, Qt::Orientation orientation, 
                                  int role) const
 {
@@ -341,12 +363,7 @@ QVariant RecollModel::headerData(int idx, Qt::Orientation orientation,
     }
     if (orientation == Qt::Horizontal && role == Qt::DisplayRole &&
         idx < int(m_fields.size())) {
-        map<string, QString>::const_iterator it = 
-            o_displayableFields.find(m_fields[idx]);
-        if (it == o_displayableFields.end())
-            return QString::fromUtf8(m_fields[idx].c_str());
-        else 
-            return it->second;
+        return displayableField(m_fields[idx]);
     }
     return QVariant();
 }
@@ -360,11 +377,16 @@ QVariant RecollModel::data(const QModelIndex& index, int role) const
     // this to adjust the row height (there is probably a better way
     // to do it in the delegate?)
     if (role == Qt::FontRole && prefs.reslistfontsize > 0) {
-        QFont font = m_table->font();
-        int fs = prefs.reslistfontsize <= fsadjusttable ? prefs.reslistfontsize:
-            prefs.reslistfontsize - fsadjusttable;
-        font.setPointSize(fs);
-        return font;
+        if (m_reslfntszforcached != prefs.reslistfontsize) {
+            m_reslfntszforcached = prefs.reslistfontsize;
+            m_table->setDefRowHeight();
+            m_cachedfont = m_table->font();
+            int fs = prefs.reslistfontsize <= fsadjusttable ?
+                prefs.reslistfontsize: prefs.reslistfontsize - fsadjusttable;
+            if (fs > 0) 
+                m_cachedfont.setPointSize(fs);
+        }
+        return m_cachedfont;
     }    
 
     if (!m_source || role != Qt::DisplayRole || !index.isValid() ||
@@ -372,14 +394,17 @@ QVariant RecollModel::data(const QModelIndex& index, int role) const
         return QVariant();
     }
 
-    Rcl::Doc doc;
-    if (!m_source->getDoc(index.row(), doc)) {
-        return QVariant();
+    if (m_rowforcachedoc != index.row()) {
+        m_rowforcachedoc = index.row();
+        m_cachedoc = Rcl::Doc();
+        if (!m_source->getDoc(index.row(), m_cachedoc)) {
+            return QVariant();
+        }
     }
 
     string colname = m_fields[index.column()];
 
-    string data = m_getters[index.column()](colname, doc);
+    string data = m_getters[index.column()](colname, m_cachedoc);
 
 #ifndef _WIN32
     // Special case url, because it may not be utf-8. URL-encode in this case.
@@ -472,60 +497,91 @@ public:
     // difficult. Anyway, the display seems fast enough as is.
     void paint(QPainter *painter, const QStyleOptionViewItem &option, 
                const QModelIndex &index) const {
+
+        QVariant value = index.data(Qt::DisplayRole);
+        QString text;
+        if (value.isValid() && !value.isNull()) {
+            text = value.toString();
+        }
+        if (text.isEmpty()) {
+            QStyledItemDelegate::paint(painter, option, index);
+            return;
+        }
+
         QStyleOptionViewItem opt = option;
         initStyleOption(&opt, index);
-        QVariant value = index.data(Qt::DisplayRole);
-        if (value.isValid() && !value.isNull()) {
-            QString text = value.toString();
-            if (!text.isEmpty()) {
-                QTextDocument document;
-                painter->save();
-                QString fstyle;
-                if (prefs.reslistfontsize > 0) {
-                    int fs = prefs.reslistfontsize <= fsadjusttable ?
-                        prefs.reslistfontsize :
-                        prefs.reslistfontsize - fsadjusttable;
-                    fstyle = QString("font-size: %1pt").arg(fs);
-                }
-                if (opt.state & QStyle::State_Selected) {
-                    painter->fillRect(opt.rect, opt.palette.highlight());
-                    // Set the foreground color. Tried with pen
-                    // approach did not seem to work, probably it's
-                    // reset by the textdocument. Couldn't use
-                    // setdefaultstylesheet() either. the div thing is
-                    // an ugly hack. Works for now
-                    QString ntxt("<div style='color: white");
-                    if (!fstyle.isEmpty()) {
-                        ntxt += QString(";") + fstyle;
-                    }
-                    ntxt += "'>";
-                    ntxt += text + QString::fromUtf8("</div>");
-                    text.swap(ntxt);
-                } else {
-                    if (!fstyle.isEmpty()) {
-                        QString ntxt("<div style='");
-                        ntxt += fstyle;
-                        ntxt += QString("'>") + text + QString("</div>");
-                        text.swap(ntxt);
-                    }
-                }
-                painter->setClipRect(option.rect);
-                QPoint where = option.rect.topLeft();
-                where.ry() += TEXTINCELLVTRANS;
-                painter->translate(where);
-                document.setHtml(text);
-                document.drawContents(painter);
-                painter->restore();
-                return;
-            } 
+
+        painter->save();
+
+        /* As we draw with a text document, not the normal tableview
+           painter, we need to retrieve the appropriate colors and set
+           them as HTML styles. */
+        QString color = opt.palette.color(QPalette::Base).name();
+        QString textcolor = opt.palette.color(QPalette::Text).name();
+        QString selcolor = opt.palette.color(QPalette::Highlight).name();
+        QString seltextcolor =
+            opt.palette.color(QPalette::HighlightedText).name();
+        QString fstyle;
+        if (prefs.reslistfontsize > 0) {
+            int fs = prefs.reslistfontsize <= fsadjusttable ?
+                prefs.reslistfontsize : prefs.reslistfontsize - fsadjusttable;
+            fstyle = QString("font-size: %1pt").arg(fs);
         }
-        QStyledItemDelegate::paint(painter, option, index);
+        QString ntxt("<div style='");
+        ntxt += " color:";
+        ntxt += (opt.state & QStyle::State_Selected)? seltextcolor:textcolor;
+        ntxt += ";";
+        ntxt += " background:";
+        ntxt += (opt.state & QStyle::State_Selected)? selcolor:color;
+        ntxt += ";";
+        ntxt += fstyle;
+        ntxt += QString("'>") + text + QString("</div>");
+        text.swap(ntxt);
+        
+        painter->setClipRect(opt.rect);
+        QPoint where = option.rect.topLeft();
+        where.ry() += TEXTINCELLVTRANS;
+        painter->translate(where);
+        QTextDocument document;
+        document.setHtml(text);
+        document.drawContents(painter);
+        painter->restore();
     }
 };
 
+void ResTable::setDefRowHeight()
+{
+    QHeaderView *header = tableView->verticalHeader();
+    if (header) {
+        // Don't do this: it forces a query on the whole model (all
+        // docs) to compute the height. No idea why this was needed,
+        // things seem to work ok without it. The row height does not
+        // shrink when the font is reduced, but I'm not sure that it
+        // worked before.
+//        header->setSectionResizeMode(QHeaderView::ResizeToContents);
+        // Compute ourselves instead, for one row.
+        QFont font = tableView->font();
+        int fs = prefs.reslistfontsize <= fsadjusttable ?
+            prefs.reslistfontsize : prefs.reslistfontsize - fsadjusttable;
+        if (fs > 0)
+            font.setPointSize(fs);
+        QFontMetrics fm(font);
+        header->setDefaultSectionSize(fm.height() + ROWHEIGHTPAD);
+    }
+}
+
 void ResTable::init()
 {
-    if (!(m_model = new RecollModel(prefs.restableFields, this)))
+    QSettings settings;
+    auto restableFields = settings.value(settingskey_fieldlist).toStringList();
+    if (restableFields.empty()) {
+        restableFields.push_back("date");
+        restableFields.push_back("title");
+        restableFields.push_back("filename");
+        restableFields.push_back("author");
+        restableFields.push_back("url");
+    }
+    if (!(m_model = new RecollModel(restableFields, this)))
         return;
     tableView->setModel(m_model);
     tableView->setMouseTracking(true);
@@ -542,9 +598,16 @@ void ResTable::init()
 
     QHeaderView *header = tableView->horizontalHeader();
     if (header) {
-        if (int(prefs.restableColWidths.size()) == header->count()) {
+        QString qw = settings.value(settingskey_fieldwiths).toString();
+        vector<string> vw;
+        stringToStrings(qs2utf8s(qw), vw);
+        vector<int> restableColWidths;
+        for (const auto& w : vw) {
+            restableColWidths.push_back(atoi(w.c_str()));
+        }
+        if (int(restableColWidths.size()) == header->count()) {
             for (int i = 0; i < header->count(); i++) {
-                header->resizeSection(i, prefs.restableColWidths[i]);
+                header->resizeSection(i, restableColWidths[i]);
             }
         }
         header->setSortIndicatorShown(true);
@@ -562,12 +625,7 @@ void ResTable::init()
     header->setMovable(true);
 #endif
 
-    header = tableView->verticalHeader();
-    if (header) {
-        header->setDefaultSectionSize(QApplication::fontMetrics().height() + 
-                                      ROWHEIGHTPAD);
-        header->setSectionResizeMode(QHeaderView::ResizeToContents);        
-    }
+    setDefRowHeight();
 
     QShortcut *sc = new QShortcut(QKeySequence(Qt::Key_Escape), this);
     connect(sc, SIGNAL(activated()), tableView->selectionModel(), SLOT(clear()));
@@ -580,8 +638,18 @@ void ResTable::init()
     m_pager = new ResTablePager(this);
     m_pager->setHighLighter(&g_hiliter);
 
-    QSettings settings;
-    QVariant saved = settings.value("resTableSplitterSizes");
+    deleteZ(textBrowser);
+    m_detail = new ResTableDetailArea(this);
+    m_detail->setReadOnly(true);
+    m_detail->setUndoRedoEnabled(false);
+    m_detail->setOpenLinks(false);
+    m_detail->init();
+    // signals and slots connections
+    connect(m_detail, SIGNAL(anchorClicked(const QUrl &)), 
+            this, SLOT(linkWasClicked(const QUrl &)));
+    splitter->addWidget(m_detail);
+    splitter->setOrientation(Qt::Vertical);
+    QVariant saved = settings.value(settingskey_splittersizes);
     if (saved != QVariant()) {
         splitter->restoreState(saved.toByteArray());
     } else {
@@ -589,18 +657,6 @@ void ResTable::init()
         sizes << 355 << 125;
         splitter->setSizes(sizes);
     }
-
-    deleteZ(textBrowser);
-    m_detail = new ResTableDetailArea(this);
-    m_detail->setReadOnly(true);
-    m_detail->setUndoRedoEnabled(false);
-    m_detail->setOpenLinks(false);
-    m_detail->setFont();
-    // signals and slots connections
-    connect(m_detail, SIGNAL(anchorClicked(const QUrl &)), 
-            this, SLOT(linkWasClicked(const QUrl &)));
-    splitter->addWidget(m_detail);
-    splitter->setOrientation(Qt::Vertical);
     installEventFilter(this);
 }
 
@@ -653,8 +709,9 @@ void ResTable::setRclMain(RclMain *m, bool ismain)
 
 void ResTable::onUiPrefsChanged()
 {
-    if (m_detail)
-        m_detail->setFont();
+    if (m_detail) {
+        m_detail->init();
+    }        
 }
 
 int ResTable::getDetailDocNumOrTopRow()
@@ -671,7 +728,7 @@ void ResTable::makeRowVisible(int row)
     QModelIndex modelIndex = m_model->index(row, 0);
     tableView->scrollTo(modelIndex, QAbstractItemView::PositionAtTop);
     tableView->selectionModel()->clear();
-    m_detail->clear();
+    m_detail->init();
     m_detaildocnum = -1;
 }
 
@@ -681,7 +738,7 @@ void ResTable::saveColState()
     if (!m_ismainres)
         return;
     QSettings settings;
-    settings.setValue("resTableSplitterSizes", splitter->saveState());
+    settings.setValue(settingskey_splittersizes, splitter->saveState());
 
     QHeaderView *header = tableView->horizontalHeader();
     const vector<string>& vf = m_model->getFields();
@@ -693,18 +750,18 @@ void ResTable::saveColState()
     // Remember the current column order. Walk in visual order and
     // create new list
     QStringList newfields;
-    vector<int> newwidths;
+    QString newwidths;
     for (int vi = 0; vi < header->count(); vi++) {
         int li = header->logicalIndex(vi);
         if (li < 0 || li >= int(vf.size())) {
             LOGERR("saveColState: logical index beyond list size!\n");
             continue;
         }
-        newfields.push_back(QString::fromUtf8(vf[li].c_str()));
-        newwidths.push_back(header->sectionSize(li));
+        newfields.push_back(u8s2qs(vf[li]));
+        newwidths += QString().setNum(header->sectionSize(li)) + QString(" ");
     }
-    prefs.restableFields = newfields;
-    prefs.restableColWidths = newwidths;
+    settings.setValue(settingskey_fieldlist, newfields);
+    settings.setValue(settingskey_fieldwiths, newwidths);
 }
 
 void ResTable::onTableView_currentChanged(const QModelIndex& index)
@@ -716,11 +773,11 @@ void ResTable::onTableView_currentChanged(const QModelIndex& index)
         return;
     Rcl::Doc doc;
     if (m_model->getDocSource()->getDoc(index.row(), doc)) {
-        m_detail->clear();
+        m_detail->init();
         m_detaildocnum = index.row();
         m_detaildoc = doc;
-        m_pager->displayDoc(theconfig, index.row(), m_detaildoc, 
-                            m_model->m_hdata);
+        m_pager->displaySingleDoc(theconfig, m_detaildocnum, m_detaildoc, 
+                                  m_model->m_hdata);
         emit(detailDocChanged(doc, m_model->getDocSource()));
     } else {
         m_detaildocnum = -1;
@@ -749,7 +806,7 @@ void ResTable::setDocSource(std::shared_ptr<DocSequence> nsource)
     if (m_pager)
         m_pager->setDocSource(nsource, 0);
     if (m_detail)
-        m_detail->clear();
+        m_detail->init();
     m_detaildocnum = -1;
 }
 
@@ -770,8 +827,8 @@ void ResTable::saveAsCSV()
     if (s.isEmpty())
         return;
     std::string tofile = qs2path(s);
-    std::fstream fp = path_open(tofile, std::ios::out|std::ios::trunc);
-    if (!fp.is_open()) {
+    std::fstream fp;
+    if (!path_streamopen(tofile, std::ios::out|std::ios::trunc,fp)) {
         QMessageBox::warning(0, "Recoll", 
                              tr("Can't open/create file: ") + s);
         return;
@@ -829,7 +886,7 @@ void ResTable::readDocSource(bool resetPos)
         m_model->m_hdata.clear();
     }
     m_model->readDocSource();
-    m_detail->clear();
+    m_detail->init();
     m_detaildocnum = -1;
 }
 
@@ -842,19 +899,23 @@ void ResTable::linkWasClicked(const QUrl &url)
     const char *ascurl = s.toUtf8();
     LOGDEB("ResTable::linkWasClicked: [" << ascurl << "]\n");
 
-    int i = atoi(ascurl+1) -1;
+    int docseqnum = atoi(ascurl+1) -1;
+    if (m_detaildocnum != docseqnum) {
+        //? Really we should abort...
+        LOGERR("ResTable::linkWasClicked: m_detaildocnum != docseqnum !\n");
+        return;
+    }
+    
     int what = ascurl[0];
     switch (what) {
         // Open abstract/snippets window
     case 'A':
-        if (m_detaildocnum >= 0)
-            emit(showSnippets(m_detaildoc));
+        emit(showSnippets(m_detaildoc));
         break;
     case 'D':
     {
         vector<Rcl::Doc> dups;
-        if (m_detaildocnum >= 0 && m_rclmain && 
-            m_model->getDocSource()->docDups(m_detaildoc, dups)) {
+        if (m_rclmain && m_model->getDocSource()->docDups(m_detaildoc, dups)) {
             m_rclmain->newDupsW(m_detaildoc, dups);
         }
     }
@@ -863,8 +924,7 @@ void ResTable::linkWasClicked(const QUrl &url)
     // Open parent folder
     case 'F':
     {
-        emit editRequested(ResultPopup::getParent(
-                               std::shared_ptr<DocSequence>(), m_detaildoc));
+        emit editRequested(ResultPopup::getFolder(m_detaildoc));
     }
     break;
 
@@ -873,7 +933,7 @@ void ResTable::linkWasClicked(const QUrl &url)
     {
         if (what == 'P') {
             if (m_ismainres) {
-                emit docPreviewClicked(i, m_detaildoc, 0);
+                emit docPreviewClicked(docseqnum, m_detaildoc, 0);
             }  else {
                 emit previewRequested(m_detaildoc);
             }
@@ -914,7 +974,7 @@ void ResTable::onDoubleClick(const QModelIndex& index)
     Rcl::Doc doc;
     if (m_model->getDocSource()->getDoc(index.row(), doc)) {
         if (m_detaildocnum != index.row()) {
-            m_detail->clear();
+            m_detail->init();
             m_detaildocnum = index.row();
             m_pager->displayDoc(theconfig, index.row(), m_detaildoc, 
                                 m_model->m_hdata);
@@ -1003,9 +1063,23 @@ void ResTable::menuPreviewParent()
 
 void ResTable::menuOpenParent()
 {
-    if (m_detaildocnum >= 0 && m_model && m_model->getDocSource())
-        emit editRequested(
-            ResultPopup::getParent(m_model->getDocSource(), m_detaildoc));
+    if (m_detaildocnum >= 0 && m_model && m_model->getDocSource()) {
+        Rcl::Doc pdoc =
+            ResultPopup::getParent(m_model->getDocSource(), m_detaildoc);
+        if (!pdoc.url.empty()) {
+            emit editRequested(pdoc);
+        }
+    }
+}
+
+void ResTable::menuOpenFolder()
+{
+    if (m_detaildocnum >= 0) {
+        Rcl::Doc pdoc = ResultPopup::getFolder(m_detaildoc);
+        if (!pdoc.url.empty()) {
+            emit editRequested(pdoc);
+        }
+    }
 }
 
 void ResTable::menuEdit()
@@ -1085,12 +1159,11 @@ void ResTable::createHeaderPopupMenu(const QPoint& pos)
     popup->addSeparator();
 
     QAction *act;
-    for (map<string, QString>::const_iterator it = allfields.begin();
-         it != allfields.end(); it++) {
-        if (std::find(fields.begin(), fields.end(), it->first) != fields.end())
+    for (const auto& field : allfields) {
+        if (std::find(fields.begin(), fields.end(), field.first) != fields.end())
             continue;
-        act = new QAction(tr("Add \"%1\" column").arg(it->second), popup);
-        act->setData(QString::fromUtf8(it->first.c_str()));
+        act = new QAction(tr("Add \"%1\" column").arg(field.second), popup);
+        act->setData(u8s2qs(field.first));
         connect(act, SIGNAL(triggered(bool)), this , SLOT(addColumn()));
         popup->addAction(act);
     }
