@@ -56,10 +56,10 @@ public:
     virtual std::shared_ptr<DocSequence> getDocSource() {return m_source;}
     virtual void deleteColumn(int);
     virtual const std::vector<std::string>& getFields() {return m_fields;}
-    virtual const std::map<std::string, QString>& getAllFields() 
-    { 
-    return o_displayableFields;
+    static const std::map<std::string, QString>& getAllFields() { 
+        return o_displayableFields;
     }
+    static QString displayableField(const std::string& in);
     virtual void addColumn(int, const std::string&);
     // Some column name are aliases/translator for base document field 
     // (ie: date, datetime->mtime). Help deal with this:
@@ -82,6 +82,11 @@ private:
     bool m_ignoreSort;
     FieldGetter* chooseGetter(const std::string&);
     HighlightData m_hdata;
+    // Things we cache because we are repeatedly asked for the same.
+    mutable QFont m_cachedfont;
+    mutable int   m_reslfntszforcached{-1};
+    mutable Rcl::Doc m_cachedoc;
+    mutable int m_rowforcachedoc{-1};
 };
 
 class ResTable;
@@ -96,7 +101,8 @@ class ResTableDetailArea : public QTextBrowser {
  public slots:
     virtual void createPopupMenu(const QPoint& pos);
     virtual void setFont();
-    
+    virtual void init();
+
 private:
     ResTable *m_table;
 };
@@ -126,6 +132,7 @@ public:
     virtual int getDetailDocNumOrTopRow();
 
     void setRclMain(RclMain *m, bool ismain);
+    void setDefRowHeight();
 
 public slots:
     virtual void onTableView_currentChanged(const QModelIndex&);
@@ -148,6 +155,7 @@ public slots:
     virtual void menuExpand();
     virtual void menuPreviewParent();
     virtual void menuOpenParent();
+    virtual void menuOpenFolder();
     virtual void menuShowSnippets();
     virtual void menuShowSubDocs();
     virtual void createHeaderPopupMenu(const QPoint&);
