@@ -170,7 +170,7 @@ void SSearch::init()
     connect(clearqPB, SIGNAL(clicked()), queryText, SLOT(clear()));
     connect(searchPB, SIGNAL(clicked()), this, SLOT(startSimpleSearch()));
     connect(searchTypCMB, SIGNAL(activated(int)), this,
-            SLOT(searchTypeChanged(int)));
+            SLOT(onSearchTypeChanged(int)));
 
     m_completermodel = new RclCompleterModel(this);
     m_completer = new QCompleter(m_completermodel, this);
@@ -187,6 +187,25 @@ void SSearch::init()
     connect(m_completer, SIGNAL(activated(const QString&)), this,
             SLOT(onCompletionActivated(const QString&)));
     connect(historyPB, SIGNAL(clicked()), this, SLOT(onHistoryClicked()));
+    setupButtons();
+}
+
+void SSearch::setupButtons()
+{
+    if (prefs.noClearSearch) {
+        clearqPB->hide();
+        searchPB->hide();
+        queryText->setClearButtonEnabled(true);
+    } else {
+        clearqPB->show();
+        searchPB->show();
+        queryText->setClearButtonEnabled(false);
+    }
+    if (prefs.noSSTypCMB) {
+        searchTypCMB->hide();
+    } else {
+        searchTypCMB->show();
+    }
 }
 
 void SSearch::takeFocus()
@@ -355,9 +374,15 @@ void SSearch::searchTextChanged(const QString& text)
     }
 }
 
-void SSearch::searchTypeChanged(int typ)
+void SSearch::onSearchTypeChanged(int typ)
 {
     LOGDEB1("Search type now " << typ << "\n");
+
+    // This may come from the menus or the combobox. Ensure that
+    // things are in sync. No loop because we are connected to
+    // combobox or menu activated(), not currentIndexChanged()
+    searchTypCMB->setCurrentIndex(typ);
+    
     // Adjust context help
     if (typ == SST_LANG) {
         HelpClient::installMap((const char *)this->objectName().toUtf8(), 
@@ -470,7 +495,7 @@ bool SSearch::startSimpleSearch(const string& u8, int maxexp)
     xml << "  <T>" << base64_encode(u8) << "</T>\n";
 
     SSearchType tp = (SSearchType)searchTypCMB->currentIndex();
-    Rcl::SearchData *sdata = 0;
+    std::shared_ptr<Rcl::SearchData> sdata;
 
     if (tp == SST_LANG) {
         xml << "  <SM>QL</SM>\n";
@@ -484,14 +509,14 @@ bool SSearch::startSimpleSearch(const string& u8, int maxexp)
         } else {
             sdata = wasaStringToRcl(theconfig, stemlang, u8, reason);
         }
-        if (sdata == 0) {
+        if (!sdata) {
             QMessageBox::warning(0, "Recoll", tr("Bad query string") + ": " +
                                  QString::fromUtf8(reason.c_str()));
             return false;
         }
     } else {
-        sdata = new Rcl::SearchData(Rcl::SCLT_OR, stemlang);
-        if (sdata == 0) {
+        sdata = std::make_shared<Rcl::SearchData>(Rcl::SCLT_OR, stemlang);
+        if (!sdata) {
             QMessageBox::warning(0, "Recoll", tr("Out of memory"));
             return false;
         }
@@ -529,9 +554,8 @@ bool SSearch::startSimpleSearch(const string& u8, int maxexp)
     m_xml = xml.str();
     LOGDEB("SSearch::startSimpleSearch:xml:[" << m_xml << "]\n");
 
-    std::shared_ptr<Rcl::SearchData> rsdata(sdata);
     emit setDescription(u8s2qs(u8));
-    emit startSearch(rsdata, true);
+    emit startSearch(sdata, true);
     return true;
 }
 
