@@ -84,9 +84,10 @@ public:
     virtual bool fromXML(const SSearchDef& fxml);
     virtual QString currentText();
     virtual bool eventFilter(QObject *target, QEvent *event);
-                                  
+    virtual void setupButtons();
+                               
 public slots:
-    virtual void searchTypeChanged(int);
+    virtual void onSearchTypeChanged(int);
     virtual void setSearchString(const QString& text);
     virtual void startSimpleSearch();
     virtual void addTerm(QString);
