@@ -144,6 +144,11 @@ void UIPrefsDialog::setFromPrefs()
 
     keepSortCB->setChecked(prefs.keepSort);
 
+    noToolbarsCB->setChecked(prefs.noToolbars);
+    noClearSearchCB->setChecked(prefs.noClearSearch);
+    noStatusBarCB->setChecked(prefs.noStatusBar);
+    noMenuBarCB->setChecked(prefs.noMenuBar);
+    noSSTypCMBCB->setChecked(prefs.noSSTypCMB);
     showTrayIconCB->setChecked(prefs.showTrayIcon);
     if (!prefs.showTrayIcon) {
         prefs.closeToTray = false;
@@ -235,11 +240,14 @@ void UIPrefsDialog::setFromPrefs()
     autoSuffsCB->setChecked(prefs.autoSuffsEnable);
     autoSuffsLE->setText(prefs.autoSuffs);
 
-    synFileCB->setChecked(prefs.synFileEnable);
     synFile = prefs.synFile;
     if (synFile.isEmpty()) {
+        synFileCB->setChecked(false);
+        synFileCB->setEnabled(false);
         synFilePB->setText(tr("Choose"));
     } else {
+        synFileCB->setChecked(prefs.synFileEnable);
+        synFileCB->setEnabled(true);
         string nm = path_getsimple(qs2path(synFile));
         synFilePB->setText(path2qs(nm));
     }
@@ -255,7 +263,7 @@ void UIPrefsDialog::setFromPrefs()
     for (const auto& dbdir : prefs.activeExtraDbs) {
         auto items =
             idxLV->findItems(path2qs(dbdir), 
-                              Qt::MatchFixedString|Qt::MatchCaseSensitive);
+                             Qt::MatchFixedString|Qt::MatchCaseSensitive);
         for (auto& entry : items) {
             entry->setCheckState(Qt::Checked);
         }
@@ -344,6 +352,15 @@ void UIPrefsDialog::accept()
     prefs.startWithAdvSearchOpen = initStartAdvCB->isChecked();
 
     prefs.keepSort = keepSortCB->isChecked();
+    prefs.noToolbars = noToolbarsCB->isChecked();
+    m_mainWindow->setupToolbars();
+    prefs.noMenuBar = noMenuBarCB->isChecked();
+    m_mainWindow->setupMenus();
+    prefs.noSSTypCMB = noSSTypCMBCB->isChecked();
+    prefs.noStatusBar = noStatusBarCB->isChecked();
+    m_mainWindow->setupStatusBar();
+    prefs.noClearSearch = noClearSearchCB->isChecked();
+    m_mainWindow->sSearch->setupButtons();
     prefs.showTrayIcon = showTrayIconCB->isChecked();
     m_mainWindow->enableTrayIcon(prefs.showTrayIcon);
     prefs.closeToTray = closeToTrayCB->isChecked();
@@ -469,10 +486,14 @@ void UIPrefsDialog::showStylesheetDialog()
     }
 }
 
-void UIPrefsDialog::resetStylesheet()
+void UIPrefsDialog::resetStylesheet(QString fn)
 {
-    qssFile = "";
-    stylesheetPB->setText(tr("Choose"));
+    qssFile = fn;
+    if (fn.isEmpty()) {
+        stylesheetPB->setText(tr("Choose"));
+    } else {
+        stylesheetPB->setText(fn);
+    }
 }
 void UIPrefsDialog::showSnipCssDialog()
 {
@@ -489,8 +510,17 @@ void UIPrefsDialog::resetSnipCss()
 void UIPrefsDialog::showSynFileDialog()
 {
     synFile = myGetFileName(false, "Select synonyms file", true);
-    if (synFile.isEmpty())
+    if (synFile.isEmpty()) {
+        synFileCB->setChecked(false);
+        synFileCB->setEnabled(false);
+        synFilePB->setText(tr("Choose"));
         return;
+    } else {
+        synFileCB->setChecked(prefs.synFileEnable);
+        synFileCB->setEnabled(true);
+        string nm = path_getsimple(qs2path(synFile));
+        synFilePB->setText(path2qs(nm));
+    }
     string nm = path_getsimple(qs2path(synFile));
     synFilePB->setText(path2qs(nm));
 }
@@ -585,23 +615,6 @@ void UIPrefsDialog::delExtraDbPB_clicked()
     }
 }
 
-static bool samedir(const string& dir1, const string& dir2)
-{
-#ifdef _WIN32
-    return !dir1.compare(dir2);
-#else
-    struct stat st1, st2;
-    if (stat(dir1.c_str(), &st1))
-        return false;
-    if (stat(dir2.c_str(), &st2))
-        return false;
-    if (st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino) {
-        return true;
-    }
-    return false;
-#endif
-}
-
 void UIPrefsDialog::on_showTrayIconCB_clicked()
 {
     if (!showTrayIconCB->checkState()) {
@@ -654,7 +667,7 @@ void UIPrefsDialog::addExtraDbPB_clicked()
                                 " stripping option"));
         return;
     }
-    if (samedir(dbdir, theconfig->getDbDir())) {
+    if (path_samefile(dbdir, theconfig->getDbDir())) {
         QMessageBox::warning(0, "Recoll", tr("This is the main/local index!"));
         return;
     }
@@ -662,7 +675,7 @@ void UIPrefsDialog::addExtraDbPB_clicked()
     for (int i = 0; i < idxLV->count(); i++) {
         QListWidgetItem *item = idxLV->item(i);
         string existingdir = qs2path(item->text());
-        if (samedir(dbdir, existingdir)) {
+        if (path_samefile(dbdir, existingdir)) {
             QMessageBox::warning(
                 0, "Recoll", tr("The selected directory is already in the "
                                 "index list"));
