@@ -31,8 +31,7 @@ class UIPrefsDialog : public QDialog, public Ui::uiPrefsDialogBase
 
 public:
     UIPrefsDialog(RclMain* parent)
-    : QDialog((QWidget*)parent), m_mainWindow(parent)
-    {
+        : QDialog((QWidget*)parent), m_mainWindow(parent) {
         setupUi(this);
         init();
     }
@@ -53,7 +52,7 @@ public slots:
     virtual void showStylesheetDialog();
     virtual void showSynFileDialog();
     virtual void showSnipCssDialog();
-    virtual void resetStylesheet();
+    virtual void resetStylesheet(QString fn = QString());
     virtual void resetSnipCss();
     virtual void showViewAction();
     virtual void showViewAction(const QString& mt);
