@@ -24,6 +24,7 @@
 #include <limits.h>
 
 #include <iostream>
+#include <sstream>
 #include <list>
 #include <string>
 
@@ -57,8 +58,29 @@ bool dump_contents(RclConfig *rclconfig, Rcl::Doc& idoc)
     return true;
 }
 
+string make_abstract(Rcl::Doc& doc, Rcl::Query& query, bool asSnippets,
+                     int snipcount)
+{
+    string abstract;
+    if (asSnippets) {
+        std::vector<Rcl::Snippet> snippets;
+        std::ostringstream str;
+        if (query.makeDocAbstract(doc, snippets, snipcount, -1, true)) {
+            for (const auto snippet : snippets) {
+                str << snippet.page << " : " << snippet.snippet << endl;
+            }
+        }
+        abstract = str.str();
+    } else {
+        query.makeDocAbstract(doc, abstract);
+        abstract += "\n";
+    }
+    return abstract;
+}
+
 void output_fields(vector<string> fields, Rcl::Doc& doc,
-                   Rcl::Query& query, Rcl::Db&, bool printnames)
+                   Rcl::Query& query, Rcl::Db&, bool printnames,
+                   bool asSnippets, int snipcnt)
 {
     if (fields.empty()) {
         map<string,string>::const_iterator it;
@@ -70,9 +92,7 @@ void output_fields(vector<string> fields, Rcl::Doc& doc,
          it != fields.end(); it++) {
         string out;
         if (!it->compare("abstract")) {
-            string abstract;
-            query.makeDocAbstract(doc, abstract);
-            base64_encode(abstract, out);
+            base64_encode(make_abstract(doc, query, asSnippets, snipcnt), out);
         } else if (!it->compare("xdocid")) {
             char cdocid[30];
             sprintf(cdocid, "%lu", (unsigned long)doc.xdocid);
@@ -117,6 +137,7 @@ static char usage [] =
 " -Q : no result lines, just the processed query and result count.\n"
 " -m : dump the whole document meta[] array for each result.\n"
 " -A : output the document abstracts.\n"
+"    -p <cnt> : show <cnt> snippets, with page numbers instead of the concatenated abstract.\n"
 " -S fld : sort by field <fld>.\n"
 "   -D : sort descending.\n"
 " -s stemlang : set stemming language to use (must exist in index...).\n"
@@ -167,18 +188,19 @@ static int     op_flags;
 #define OPT_n     0x4000
 // GUI: -o same
 #define OPT_o     0x8000
-#define OPT_P     0x10000
-#define OPT_Q     0x20000
+#define OPT_p     0x10000
+#define OPT_P     0x20000
+#define OPT_Q     0x40000
 // GUI: -q same
-#define OPT_q     0x40000
-#define OPT_S     0x80000
-#define OPT_s     0x100000
-#define OPT_T     0x200000
+#define OPT_q     0x80000
+#define OPT_S     0x100000
+#define OPT_s     0x2000000
+#define OPT_T     0x4000000
 // GUI: -t use command line, us: ignored
-#define OPT_t     0x400000
+#define OPT_t     0x800000
 // GUI uses -v : show version. Us: usage
 // GUI uses -w : open minimized
-#define OPT_E     0x800000
+#define OPT_E     0x1000000
 
 int recollq(RclConfig **cfp, int argc, char **argv)
 {
@@ -192,6 +214,8 @@ int recollq(RclConfig **cfp, int argc, char **argv)
     
     int firstres = 0;
     int maxcount = 2000;
+    int snipcnt = -1;
+    
     thisprog = argv[0];
     argc--; argv++;
 
@@ -245,6 +269,18 @@ int recollq(RclConfig **cfp, int argc, char **argv)
             argc--; goto b1;
             case 'o':   op_flags |= OPT_o; break;
             case 'P':   op_flags |= OPT_P; break;
+            case 'p':
+            {
+                op_flags |= OPT_p;
+                if (argc < 2)
+                    Usage();
+                const char *cp = *(++argv);
+                char *cpe;
+                snipcnt = strtol(cp, &cpe, 10);
+                if (*cpe != 0)
+                    Usage();
+                argc--; goto b1;
+            }
             case 'q':   op_flags |= OPT_q; break;
             case 'Q':   op_flags |= OPT_Q; break;
             case 'S':   op_flags |= OPT_S; if (argc < 2)  Usage();
@@ -335,10 +371,10 @@ endopts:
         qs = uq;
     }
 
-    Rcl::SearchData *sd = 0;
+    std::shared_ptr<Rcl::SearchData> sd;
 
     if (op_flags & (OPT_a|OPT_o|OPT_f)) {
-        sd = new Rcl::SearchData(Rcl::SCLT_OR, stemlang);
+        sd = std::make_shared<Rcl::SearchData>(Rcl::SCLT_OR, stemlang);
         Rcl::SearchDataClause *clp = 0;
         if (op_flags & OPT_f) {
             clp = new Rcl::SearchDataClauseFilename(qs);
@@ -402,7 +438,8 @@ endopts:
             break;
 
         if (op_flags & OPT_F) {
-            output_fields(fields, doc, query, rcldb, op_flags & OPT_N);
+            output_fields(fields, doc, query, rcldb,
+                          op_flags & OPT_N, op_flags & OPT_p, snipcnt);
             continue;
         }
 
@@ -435,11 +472,13 @@ endopts:
                 }
             }
             if (op_flags & OPT_A) {
-                string abstract;
-                if (query.makeDocAbstract(doc, abstract)) {
-                    cout << "ABSTRACT" << endl;
-                    cout << abstract << endl;
-                    cout << "/ABSTRACT" << endl;
+                bool asSnippets = (op_flags & OPT_p) != 0;
+                string abstract = make_abstract(doc, query, asSnippets, snipcnt);
+                string marker = asSnippets ? "SNIPPETS" : "ABSTRACT";
+                if (!abstract.empty()) {
+                    cout << marker << endl;
+                    cout << abstract;
+                    cout << string("/") + marker << endl;
                 }
             }
         }
@@ -450,4 +489,3 @@ endopts:
 
     return 0;
 }
-
