@@ -79,9 +79,16 @@ public:
     }
     void resultPageNext();
     void resultPageFor(int docnum);
+
+    /* Display page of results */
     void displayPage(RclConfig *);
+    /* Display page with single document */
+    void displaySingleDoc(RclConfig *config, int idx,
+                          Rcl::Doc& doc, const HighlightData& hdata);
+    /* Generate HTML for single document inside page */
     void displayDoc(RclConfig *, int idx, Rcl::Doc& doc, 
                     const HighlightData& hdata, const string& sh = "");
+
     bool pageEmpty() {return m_respage.size() == 0;}
 
     string queryDescription() {
@@ -95,6 +102,9 @@ public:
     virtual bool append(const string& data, int, const Rcl::Doc&) {
             return append(data);
     }
+    /* Implementing this allows accumulating the text and setting the HTML 
+       at once */
+    virtual bool flush() {return true;}
     // Translation function. This is reimplemented in the qt reslist
     // object For this to work, the strings must be duplicated inside
     // reslist.cpp (see the QT_TR_NOOP in there). Very very unwieldy.
