@@ -478,7 +478,7 @@ void Query::Native::abstractCreateSnippetsVector(
         }
         Utf8Iter uit(ent.second);
         bool newcjk = false;
-        if (TextSplit::isCJK(*uit))
+        if (TextSplit::isNGRAMMED(*uit))
             newcjk = true;
         if (!incjk || (incjk && !newcjk))
             chunk += " ";
@@ -502,7 +502,7 @@ void Query::Native::abstractCreateSnippetsVector(
 int Query::Native::abstractFromIndex(
     Rcl::Db::Native *ndb,
     Xapian::docid docid,
-    const vector<string>& matchTerms,
+    const vector<string>&,
     const multimap<double, vector<string>> byQ,
     double totalweight,
     int ctxwords,
