@@ -15,7 +15,6 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#ifndef TEST_CIRCACHE
 #include "autoconfig.h"
 
 #include "circache.h"
@@ -235,13 +234,15 @@ public:
     bool khEnter(const string& udi, int64_t ofs) {
         UdiH h(udi);
 
-        LOGDEB2("Circache::khEnter: h " << h.asHexString() << " offs " << ofs << " udi [" << udi << "]\n");
+        LOGDEB2("Circache::khEnter: h " << h.asHexString() << " offs " <<
+                ofs << " udi [" << udi << "]\n");
 
         pair<kh_type::iterator, kh_type::iterator> p = m_ofskh.equal_range(h);
 
         if (p.first != m_ofskh.end() && p.first->first == h) {
             for (kh_type::iterator it = p.first; it != p.second; it++) {
-                LOGDEB2("Circache::khEnter: col h " << it->first.asHexString() << ", ofs " << it->second << "\n");
+                LOGDEB2("Circache::khEnter: col h " << it->first.asHexString() <<
+                        ", ofs " << it->second << "\n");
                 if (it->second == ofs) {
                     // (h,offs) already there. Happens
                     LOGDEB2("Circache::khEnter: already there\n");
@@ -255,8 +256,9 @@ public:
     }
     void khDump() {
         for (kh_type::const_iterator it = m_ofskh.begin();
-                it != m_ofskh.end(); it++) {
-            LOGDEB("Circache::KHDUMP: " << it->first.asHexString() << " " << it->second << "\n");
+             it != m_ofskh.end(); it++) {
+            LOGDEB("Circache::KHDUMP: " << it->first.asHexString() << " " <<
+                   it->second << "\n");
         }
     }
 
@@ -268,7 +270,8 @@ public:
 
         UdiH h(udi);
 
-        LOGDEB2("Circache::khFind: h " << h.asHexString() << " udi [" << udi << "]\n");
+        LOGDEB2("Circache::khFind: h " << h.asHexString() << " udi [" << udi <<
+                "]\n");
 
         pair<kh_type::iterator, kh_type::iterator> p = m_ofskh.equal_range(h);
 
@@ -280,7 +283,8 @@ public:
             LOGDEB("KHFIND: SECOND END()\n");
         }
         if (!(p.first->first == h))
-            LOGDEB("KHFIND: NOKEY: " << p.first->first.asHexString() << " " << p.second->first.asHexString() << "\n");
+            LOGDEB("KHFIND: NOKEY: " << p.first->first.asHexString() << " " <<
+                   p.second->first.asHexString() << "\n");
 #endif
 
         if (p.first == m_ofskh.end() || !(p.first->first == h)) {
@@ -309,7 +313,7 @@ public:
     // Clear entries for vector of udi/offs
     bool khClear(const vector<pair<string, int64_t> >& udis) {
         for (vector<pair<string, int64_t> >::const_iterator it = udis.begin();
-                it != udis.end(); it++) {
+             it != udis.end(); it++) {
             khClear(*it);
         }
         return true;
@@ -367,15 +371,15 @@ public:
 
         ostringstream s;
         s <<
-          "maxsize = " << m_maxsize << "\n" <<
-          "oheadoffs = " << m_oheadoffs << "\n" <<
-          "nheadoffs = " << m_nheadoffs << "\n" <<
-          "npadsize = " << m_npadsize   << "\n" <<
-          "unient = " << m_uniquentries << "\n" <<
-          "                                                              " <<
-          "                                                              " <<
-          "                                                              " <<
-          "\0";
+            "maxsize = " << m_maxsize << "\n" <<
+            "oheadoffs = " << m_oheadoffs << "\n" <<
+            "nheadoffs = " << m_nheadoffs << "\n" <<
+            "npadsize = " << m_npadsize   << "\n" <<
+            "unient = " << m_uniquentries << "\n" <<
+            "                                                              " <<
+            "                                                              " <<
+            "                                                              " <<
+            "\0";
 
         int sz = int(s.str().size());
         assert(sz < CIRCACHE_FIRSTBLOCK_SIZE);
@@ -397,38 +401,33 @@ public:
 
         lseek(m_fd, 0, 0);
         if (read(m_fd, bf, CIRCACHE_FIRSTBLOCK_SIZE) !=
-                CIRCACHE_FIRSTBLOCK_SIZE) {
+            CIRCACHE_FIRSTBLOCK_SIZE) {
             m_reason << "readfirstblock: read() failed: errno " << errno;
             return false;
         }
         string s(bf, CIRCACHE_FIRSTBLOCK_SIZE);
         ConfSimple conf(s, 1);
-        string value;
-        if (!conf.get("maxsize", value, cstr_null)) {
+        m_maxsize = conf.getInt("maxsize", -1);
+        if (m_maxsize == -1) {
             m_reason << "readfirstblock: conf get maxsize failed";
             return false;
         }
-        m_maxsize = atoll(value.c_str());
-        if (!conf.get("oheadoffs", value, cstr_null)) {
+        m_oheadoffs = conf.getInt("oheadoffs", -1);
+        if (m_oheadoffs == -1) {
             m_reason << "readfirstblock: conf get oheadoffs failed";
             return false;
         }
-        m_oheadoffs = atoll(value.c_str());
-        if (!conf.get("nheadoffs", value, cstr_null)) {
+        m_nheadoffs = conf.getInt("nheadoffs", -1);
+        if (m_nheadoffs == -1) {
             m_reason << "readfirstblock: conf get nheadoffs failed";
             return false;
         }
-        m_nheadoffs = atoll(value.c_str());
-        if (!conf.get("npadsize", value, cstr_null)) {
+        m_npadsize = conf.getInt("npadsize", -1);
+        if (m_npadsize == -1) {
             m_reason << "readfirstblock: conf get npadsize failed";
             return false;
         }
-        m_npadsize = atoll(value.c_str());
-        if (!conf.get("unient", value, cstr_null)) {
-            m_uniquentries = false;
-        } else {
-            m_uniquentries = stringToBool(value);
-        }
+        m_uniquentries = conf.getBool("unient", false);
         return true;
     }
 
@@ -444,7 +443,7 @@ public:
                  headerformat, d.dicsize, d.datasize, d.padsize, d.flags);
         if (lseek(m_fd, offset, 0) != offset) {
             m_reason << "CirCache::weh: lseek(" << offset <<
-                     ") failed: errno " << errno;
+                ") failed: errno " << errno;
             return false;
         }
         if (write(m_fd, bf, CIRCACHE_HEADER_SIZE) !=  CIRCACHE_HEADER_SIZE) {
@@ -456,8 +455,9 @@ public:
                 m_reason << "CirCache::weh: erase requested but not empty";
                 return false;
             }
-            string buf(d.padsize, ' ');
-            if (write(m_fd, buf.c_str(), d.padsize) != (ssize_t)d.padsize) {
+            string buf((size_t)d.padsize, ' ');
+            if (write(m_fd, buf.c_str(), (size_t)d.padsize) !=
+                (ssize_t)d.padsize) {
                 m_reason << "CirCache::weh: write failed. errno " << errno;
                 return false;
             }
@@ -473,7 +473,7 @@ public:
 
         if (lseek(m_fd, offset, 0) != offset) {
             m_reason << "readEntryHeader: lseek(" << offset <<
-                     ") failed: errno " << errno;
+                ") failed: errno " << errno;
             return CCScanHook::Error;
         }
         char bf[CIRCACHE_HEADER_SIZE];
@@ -491,11 +491,11 @@ public:
         if (sscanf(bf, headerformat, &d.dicsize, &d.datasize,
                    &d.padsize, &d.flags) != 4) {
             m_reason << " readEntryHeader: bad header at " <<
-                     offset << " [" << bf << "]";
+                offset << " [" << bf << "]";
             return CCScanHook::Error;
         }
-        LOGDEB2("Circache:readEntryHeader: dcsz " << d.dicsize << " dtsz " << d.datasize << " pdsz " << d.padsize <<
-                " flgs " << d.flags << "\n");
+        LOGDEB2("Circache:readEntryHeader: dcsz " << d.dicsize << " dtsz " <<
+                d.datasize << " pdsz " << d.padsize << " flgs " <<d.flags<<"\n");
         return CCScanHook::Continue;
     }
 
@@ -526,7 +526,7 @@ public:
                     startoffset = CIRCACHE_FIRSTBLOCK_SIZE;
                     continue;
                 }
-            /* FALLTHROUGH */
+                /* FALLTHROUGH */
             default:
                 return st;
             }
@@ -564,7 +564,7 @@ public:
             }
 
             startoffset += CIRCACHE_HEADER_SIZE + d.dicsize +
-                           d.datasize + d.padsize;
+                d.datasize + d.padsize;
         }
     }
 
@@ -597,7 +597,7 @@ public:
         // at the right position
         if (lseek(m_fd, offs, 0) != offs) {
             m_reason << "CirCache::get: lseek(" << offs << ") failed: " <<
-                     errno;
+                errno;
             return false;
         }
         char *bf = 0;
@@ -676,11 +676,12 @@ public:
     CCScanHookRecord()
         : headoffs(0), padsize(0) {
     }
-    virtual status takeone(int64_t offs, const string& udi,
+    virtual status takeone(int64_t offs, const string&,
                            const EntryHeaderData& d) {
         headoffs = offs;
         padsize = d.padsize;
-        LOGDEB2("CCScanHookRecord::takeone: offs " << headoffs << " padsize " << padsize << "\n");
+        LOGDEB2("CCScanHookRecord::takeone: offs " << headoffs << " padsize " <<
+                padsize << "\n");
         return Continue;
     }
 };
@@ -692,7 +693,8 @@ string CirCache::getpath()
 
 bool CirCache::create(int64_t maxsize, int flags)
 {
-    LOGDEB("CirCache::create: [" << m_dir << "] maxsz " << maxsize << " flags 0x" << std::hex << flags <<std::dec<<"\n");
+    LOGDEB("CirCache::create: [" << m_dir << "] maxsz " << maxsize <<
+           " flags 0x" << std::hex << flags <<std::dec<<"\n");
     if (m_d == 0) {
         LOGERR("CirCache::create: null data\n");
         return false;
@@ -703,19 +705,19 @@ bool CirCache::create(int64_t maxsize, int flags)
         // Directory does not exist, create it
         if (mkdir(m_dir.c_str(), 0777) < 0) {
             m_d->m_reason << "CirCache::create: mkdir(" << m_dir <<
-                          ") failed" << " errno " << errno;
+                ") failed" << " errno " << errno;
             return false;
         }
     } else {
         // If the file exists too, and truncate is not set, switch
         // to open-mode. Still may need to update header params.
         if (access(m_d->datafn(m_dir).c_str(), 0) >= 0 &&
-                !(flags & CC_CRTRUNCATE)) {
+            !(flags & CC_CRTRUNCATE)) {
             if (!open(CC_OPWRITE)) {
                 return false;
             }
             if (maxsize == m_d->m_maxsize &&
-                    ((flags & CC_CRUNIQUE) != 0) == m_d->m_uniquentries) {
+                ((flags & CC_CRUNIQUE) != 0) == m_d->m_uniquentries) {
                 LOGDEB("Header unchanged, no rewrite\n");
                 return true;
             }
@@ -733,9 +735,10 @@ bool CirCache::create(int64_t maxsize, int flags)
             }
             m_d->m_maxsize = maxsize;
             m_d->m_uniquentries = ((flags & CC_CRUNIQUE) != 0);
-            LOGDEB2("CirCache::create: rewriting header with maxsize " << m_d->m_maxsize << " oheadoffs " <<
-                    m_d->m_oheadoffs << " nheadoffs " << m_d->m_nheadoffs << " npadsize " << m_d->m_npadsize <<
-                    " unient " << m_d->m_uniquentries << "\n");
+            LOGDEB2("CirCache::create: rewriting header with maxsize " <<
+                    m_d->m_maxsize << " oheadoffs " << m_d->m_oheadoffs <<
+                    " nheadoffs " << m_d->m_nheadoffs << " npadsize " <<
+                    m_d->m_npadsize << " unient " << m_d->m_uniquentries <<"\n");
             return m_d->writefirstblock();
         }
         // Else fallthrough to create file
@@ -744,7 +747,7 @@ bool CirCache::create(int64_t maxsize, int flags)
     if ((m_d->m_fd = ::open(m_d->datafn(m_dir).c_str(),
                             O_CREAT | O_RDWR | O_TRUNC | O_BINARY, 0666)) < 0) {
         m_d->m_reason << "CirCache::create: open/creat(" <<
-                      m_d->datafn(m_dir) << ") failed " << "errno " << errno;
+            m_d->datafn(m_dir) << ") failed " << "errno " << errno;
         return false;
     }
 
@@ -755,9 +758,9 @@ bool CirCache::create(int64_t maxsize, int flags)
     char buf[CIRCACHE_FIRSTBLOCK_SIZE];
     memset(buf, 0, CIRCACHE_FIRSTBLOCK_SIZE);
     if (::write(m_d->m_fd, buf, CIRCACHE_FIRSTBLOCK_SIZE) !=
-            CIRCACHE_FIRSTBLOCK_SIZE) {
+        CIRCACHE_FIRSTBLOCK_SIZE) {
         m_d->m_reason << "CirCache::create: write header failed, errno "
-                     << errno;
+                      << errno;
         return false;
     }
     return m_d->writefirstblock();
@@ -778,7 +781,7 @@ bool CirCache::open(OpMode mode)
                             mode == CC_OPREAD ?
                             O_RDONLY | O_BINARY : O_RDWR | O_BINARY)) < 0) {
         m_d->m_reason << "CirCache::open: open(" << m_d->datafn(m_dir) <<
-                      ") failed " << "errno " << errno;
+            ") failed " << "errno " << errno;
         return false;
     }
     return m_d->readfirstblock();
@@ -789,9 +792,9 @@ public:
     virtual status takeone(int64_t offs, const string& udi,
                            const EntryHeaderData& d) {
         cout << "Scan: offs " << offs << " dicsize " << d.dicsize
-            << " datasize " << d.datasize << " padsize " << d.padsize <<
-             " flags " << d.flags <<
-             " udi [" << udi << "]" << endl;
+             << " datasize " << d.datasize << " padsize " << d.padsize <<
+            " flags " << d.flags <<
+            " udi [" << udi << "]" << endl;
         return Continue;
     }
 };
@@ -810,7 +813,7 @@ bool CirCache::dump()
         return false;
     case CCScanHook::Continue:
         cout << "Scan returns Continue ?? " << CCScanHook::Continue << " " <<
-             getReason() << endl;
+            getReason() << endl;
         return false;
     case CCScanHook::Error:
         cout << "Scan returns Error: " << getReason() << endl;
@@ -837,7 +840,8 @@ public:
 
     virtual status takeone(int64_t offs, const string& udi,
                            const EntryHeaderData& d) {
-        LOGDEB2("Circache:Scan: off " << offs << " udi [" << udi << "] dcsz " << d.dicsize << " dtsz " << d.datasize <<
+        LOGDEB2("Circache:Scan: off " << offs << " udi [" << udi << "] dcsz " <<
+                d.dicsize << " dtsz " << d.datasize <<
                 " pdsz " << d.padsize << " flgs " << d.flags << "\n");
         if (!m_udi.compare(udi)) {
             m_instance++;
@@ -873,7 +877,7 @@ bool CirCache::get(const string& udi, string& dic, string *data, int instance)
             EntryHeaderData d_good;
             int64_t           o_good = 0;
             for (vector<int64_t>::iterator it = ofss.begin();
-                    it != ofss.end(); it++) {
+                 it != ofss.end(); it++) {
                 LOGDEB1("Circache::get: trying offs " << *it << "\n");
                 EntryHeaderData d;
                 string fudi;
@@ -989,7 +993,8 @@ public:
 
     virtual status takeone(int64_t offs, const string& udi,
                            const EntryHeaderData& d) {
-        LOGDEB2("Circache:ScanSpacer:off " << offs << " dcsz " << d.dicsize << " dtsz " << d.datasize <<
+        LOGDEB2("Circache:ScanSpacer:off " << offs << " dcsz " << d.dicsize <<
+                " dtsz " << d.datasize <<
                 " pdsz " << d.padsize << " udi[" << udi << "]\n");
         sizeseen += CIRCACHE_HEADER_SIZE + d.dicsize + d.datasize + d.padsize;
         squashed_udis.push_back(make_pair(udi, offs));
@@ -1016,7 +1021,8 @@ bool CirCache::put(const string& udi, const ConfSimple *iconf,
     string dic;
     if (!iconf || !iconf->get("udi", dic) || dic.empty() || dic.compare(udi)) {
         m_d->m_reason << "No/bad 'udi' entry in input dic";
-        LOGERR("Circache::put: no/bad udi: DIC:[" << dic << "] UDI [" << udi << "]\n");
+        LOGERR("Circache::put: no/bad udi: DIC:[" << dic << "] UDI [" << udi <<
+               "]\n");
         return false;
     }
 
@@ -1060,12 +1066,13 @@ bool CirCache::put(const string& udi, const ConfSimple *iconf,
     int64_t npadsize = 0;
     bool extending = false;
 
-    LOGDEB("CirCache::put: nsz " << nsize << " oheadoffs " << m_d->m_oheadoffs << "\n");
+    LOGDEB("CirCache::put: nsz " << nsize << " oheadoffs " <<
+           m_d->m_oheadoffs << "\n");
 
     // Check if we can recover some pad space from the (physically) previous
     // entry.
     int64_t recovpadsize = m_d->m_oheadoffs == CIRCACHE_FIRSTBLOCK_SIZE ?
-                         0 : m_d->m_npadsize;
+        0 : m_d->m_npadsize;
     if (recovpadsize != 0) {
         // Need to read the latest entry's header, to rewrite it with a
         // zero pad size
@@ -1095,7 +1102,7 @@ bool CirCache::put(const string& udi, const ConfSimple *iconf,
     if (nsize <= recovpadsize) {
         // If the new entry fits entirely in the pad area from the
         // latest one, no need to recycle stuff
-        LOGDEB("CirCache::put: new fits in old padsize " << recovpadsize << "\n");
+        LOGDEB("CirCache::put: new fits in old padsize " << recovpadsize <<"\n");
         npadsize = recovpadsize - nsize;
     } else if (st.st_size < m_d->m_maxsize) {
         // Still growing the file.
@@ -1105,11 +1112,12 @@ bool CirCache::put(const string& udi, const ConfSimple *iconf,
         // Scan the file until we have enough space for the new entry,
         // and determine the pad size up to the 1st preserved entry
         int64_t scansize = nsize - recovpadsize;
-        LOGDEB("CirCache::put: scanning for size " << scansize << " from offs " << m_d->m_oheadoffs << "\n");
+        LOGDEB("CirCache::put: scanning for size " << scansize <<
+               " from offs " << m_d->m_oheadoffs << "\n");
         CCScanHookSpacer spacer(scansize);
         switch (m_d->scan(m_d->m_oheadoffs, &spacer)) {
         case CCScanHook::Stop:
-            LOGDEB("CirCache::put: Scan ok, sizeseen " << spacer.sizeseen << "\n");
+            LOGDEB("CirCache::put: Scan ok, sizeseen " << spacer.sizeseen<<"\n");
             npadsize = spacer.sizeseen - scansize;
             break;
         case CCScanHook::Eof:
@@ -1124,7 +1132,8 @@ bool CirCache::put(const string& udi, const ConfSimple *iconf,
         m_d->khClear(spacer.squashed_udis);
     }
 
-    LOGDEB("CirCache::put: writing " << nsize << " at " << nwriteoffs << " padsize " << npadsize << "\n");
+    LOGDEB("CirCache::put: writing " << nsize << " at " << nwriteoffs <<
+           " padsize " << npadsize << "\n");
 
     if (lseek(m_d->m_fd, nwriteoffs, 0) != nwriteoffs) {
         m_d->m_reason << "CirCache::put: lseek failed: " << errno;
@@ -1211,7 +1220,7 @@ bool CirCache::next(bool& eof)
 
     // Skip to next header, using values stored from previous one
     m_d->m_itoffs += CIRCACHE_HEADER_SIZE + m_d->m_ithd.dicsize +
-                     m_d->m_ithd.datasize + m_d->m_ithd.padsize;
+        m_d->m_ithd.datasize + m_d->m_ithd.padsize;
 
     // Looped back ?
     if (m_d->m_itoffs == m_d->m_oheadoffs) {
@@ -1268,7 +1277,7 @@ bool CirCache::getCurrent(string& udi, string& dic, string *data)
 // Copy all entries from occ to ncc. Both are already open.
 static bool copyall(std::shared_ptr<CirCache> occ,
                     std::shared_ptr<CirCache> ncc, int& nentries,
-    ostringstream& msg)
+                    ostringstream& msg)
 {
     bool eof = false;
     if (!occ->rewind(eof)) {
@@ -1298,7 +1307,7 @@ static bool copyall(std::shared_ptr<CirCache> occ,
         //cerr << "UDI: " << udi << endl;
         if (!ncc->put(udi, &dic, data)) {
             msg << "put failed: " << ncc->getReason() << " sdic [" << sdic <<
-                 "]" << endl;
+                "]" << endl;
             return false;
         }
         nentries++;
@@ -1342,253 +1351,3 @@ int CirCache::append(const string ddir, const string& sdir, string *reason)
 
     return nentries;
 }
-
-
-#else // TEST ->
-#include "autoconfig.h"
-
-#include <stdio.h>
-#include <stdlib.h>
-#include <errno.h>
-#include <string.h>
-#include <sys/types.h>
-#include <sys/stat.h>
-#include <unistd.h>
-
-#include <string>
-#include <iostream>
-#include <memory>
-
-#include "circache.h"
-#include "fileudi.h"
-#include "conftree.h"
-#include "readfile.h"
-#include "log.h"
-
-#include "smallut.h"
-
-using namespace std;
-
-static char *thisprog;
-
-static char usage [] =
-    " -c [-u] <dirname> <sizekbs>: create\n"
-    " -p <dirname> <apath> [apath ...] : put files\n"
-    " -d <dirname> : dump\n"
-    " -g [-i instance] [-D] <dirname> <udi>: get\n"
-    "   -D: also dump data\n"
-    " -e <dirname> <udi> : erase\n"
-    " -a <targetdir> <dir> [<dir> ...]: append old content to target\n"
-    "  The target should be first resized to hold all the data, else only\n"
-    "  as many entries as capacity permit will be retained\n"
-    ;
-
-static void
-Usage(FILE *fp = stderr)
-{
-    fprintf(fp, "%s: usage:\n%s", thisprog, usage);
-    exit(1);
-}
-
-static int     op_flags;
-#define OPT_MOINS 0x1
-#define OPT_c     0x2
-#define OPT_p     0x8
-#define OPT_g     0x10
-#define OPT_d     0x20
-#define OPT_i     0x40
-#define OPT_D     0x80
-#define OPT_u     0x100
-#define OPT_e     0x200
-#define OPT_a     0x800
-
-int main(int argc, char **argv)
-{
-    int instance = -1;
-
-    thisprog = argv[0];
-    argc--;
-    argv++;
-
-    while (argc > 0 && **argv == '-') {
-        (*argv)++;
-        if (!(**argv))
-            /* Cas du "adb - core" */
-        {
-            Usage();
-        }
-        while (**argv)
-            switch (*(*argv)++) {
-            case 'a':
-                op_flags |= OPT_a;
-                break;
-            case 'c':
-                op_flags |= OPT_c;
-                break;
-            case 'D':
-                op_flags |= OPT_D;
-                break;
-            case 'd':
-                op_flags |= OPT_d;
-                break;
-            case 'e':
-                op_flags |= OPT_e;
-                break;
-            case 'g':
-                op_flags |= OPT_g;
-                break;
-            case 'i':
-                op_flags |= OPT_i;
-                if (argc < 2) {
-                    Usage();
-                }
-                if ((sscanf(*(++argv), "%d", &instance)) != 1) {
-                    Usage();
-                }
-                argc--;
-                goto b1;
-            case 'p':
-                op_flags |= OPT_p;
-                break;
-            case 'u':
-                op_flags |= OPT_u;
-                break;
-            default:
-                Usage();
-                break;
-            }
-b1:
-        argc--;
-        argv++;
-    }
-
-    Logger::getTheLog("")->setLogLevel(Logger::LLDEB1);
-
-    if (argc < 1) {
-        Usage();
-    }
-    string dir = *argv++;
-    argc--;
-
-    CirCache cc(dir);
-
-    if (op_flags & OPT_c) {
-        if (argc != 1) {
-            Usage();
-        }
-        int64_t sizekb = atoi(*argv++);
-        argc--;
-        int flags = 0;
-        if (op_flags & OPT_u) {
-            flags |= CirCache::CC_CRUNIQUE;
-        }
-        if (!cc.create(sizekb * 1024, flags)) {
-            cerr << "Create failed:" << cc.getReason() << endl;
-            exit(1);
-        }
-    } else if (op_flags & OPT_a) {
-        if (argc < 1) {
-            Usage();
-        }
-        while (argc) {
-            string reason;
-            if (CirCache::append(dir, *argv++, &reason) < 0) {
-                cerr << reason << endl;
-                return 1;
-            }
-            argc--;
-        }
-    } else if (op_flags & OPT_p) {
-        if (argc < 1) {
-            Usage();
-        }
-        if (!cc.open(CirCache::CC_OPWRITE)) {
-            cerr << "Open failed: " << cc.getReason() << endl;
-            exit(1);
-        }
-        while (argc) {
-            string fn = *argv++;
-            argc--;
-            char dic[1000];
-            string data, reason;
-            if (!file_to_string(fn, data, &reason)) {
-                cerr << "File_to_string: " << reason << endl;
-                exit(1);
-            }
-            string udi;
-            make_udi(fn, "", udi);
-            string cmd("xdg-mime query filetype ");
-            // Should do more quoting here...
-            cmd += "'" + fn + "'";
-            FILE *fp = popen(cmd.c_str(), "r");
-            char* buf=0;
-            size_t sz = 0;
-            ::getline(&buf, &sz, fp);
-            pclose(fp);
-            string mimetype(buf);
-            free(buf);
-            trimstring(mimetype, "\n\r");
-            cout << "Got [" << mimetype << "]\n";
-
-            string s;
-            ConfSimple conf(s);
-            conf.set("udi", udi);
-            conf.set("mimetype", mimetype);
-            //ostringstream str; conf.write(str); cout << str.str() << endl;
-
-            if (!cc.put(udi, &conf, data, 0)) {
-                cerr << "Put failed: " << cc.getReason() << endl;
-                cerr << "conf: [";
-                conf.write(cerr);
-                cerr << "]" << endl;
-                exit(1);
-            }
-        }
-        cc.open(CirCache::CC_OPREAD);
-    } else if (op_flags & OPT_g) {
-        if (!cc.open(CirCache::CC_OPREAD)) {
-            cerr << "Open failed: " << cc.getReason() << endl;
-            exit(1);
-        }
-        while (argc) {
-            string udi = *argv++;
-            argc--;
-            string dic, data;
-            if (!cc.get(udi, dic, &data, instance)) {
-                cerr << "Get failed: " << cc.getReason() << endl;
-                exit(1);
-            }
-            cout << "Dict: [" << dic << "]" << endl;
-            if (op_flags & OPT_D) {
-                cout << "Data: [" << data << "]" << endl;
-            }
-        }
-    } else if (op_flags & OPT_e) {
-        if (!cc.open(CirCache::CC_OPWRITE)) {
-            cerr << "Open failed: " << cc.getReason() << endl;
-            exit(1);
-        }
-        while (argc) {
-            string udi = *argv++;
-            argc--;
-            string dic, data;
-            if (!cc.erase(udi)) {
-                cerr << "Erase failed: " << cc.getReason() << endl;
-                exit(1);
-            }
-        }
-    } else if (op_flags & OPT_d) {
-        if (!cc.open(CirCache::CC_OPREAD)) {
-            cerr << "Open failed: " << cc.getReason() << endl;
-            exit(1);
-        }
-        cc.dump();
-    } else {
-        Usage();
-    }
-
-    exit(0);
-}
-
-#endif
-
