@@ -1,4 +1,4 @@
-/* Copyright (C) 2006 J.F.Dockes
+/* Copyright (C) 2006-2019 J.F.Dockes
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU Lesser General Public License as published by
  *   the Free Software Foundation; either version 2.1 of the License, or
@@ -24,21 +24,21 @@
  *
  * Lines like '[subkey]' in the file define subsections, with independant
  * configuration namespaces. Only subsections holding at least one variable are
- * significant (empty subsections may be deleted during an update, or not)
+ * significant (empty subsections may be deleted during an update, or not).
  *
- * Whitespace around name and value is insignificant.
+ * Whitespace around name and value is ignored.
  *
- * The names are case-sensitive but don't depend on it, this might change
+ * The names are case-sensitive but don't depend on it, this might change.
  *
  * Values can be queried for, or set.
  *
- * Any line without a '=' is a comment (a line like #var = value
- * actually assigns a variable named '#var', which is not a big issue)
+ * Any line without a '=', or beginning with '[ \t]*#' is a comment.
  *
  * A configuration object can be created empty or by reading from a file or
  * a string.
- * All 'set' calls cause an immediate rewrite of the backing object if any
- * (file or string)
+ *
+ * All 'set' calls normally cause an immediate rewrite of the backing
+ * object if any (file or string). This can be prevented with holdWrites().
  *
  * The ConfTree derived class interprets the subkeys as file paths and
  * lets subdir keys hierarchically inherit the properties from
@@ -46,10 +46,9 @@
  *
  * The ConfStack class stacks several Con(Simple/Tree) objects so that
  * parameters from the top of the stack override the values from lower
- * (useful to have central/personal config files)
+ * (useful to have central/personal config files).
  */
 
-#include <time.h>
 #include <algorithm>
 #include <map>
 #include <string>
@@ -62,7 +61,6 @@
 #include <istream>
 #include <ostream>
 #endif
-#include <iostream>
 
 #include "pathut.h"
 
@@ -83,7 +81,7 @@ public:
 };
 
 /**
- * Virtual base class used to define an interface mostly useful for testing
+ * Virtual base class used to define the interface, and a few helper methods.
  */
 class ConfNull {
 public:
@@ -93,9 +91,15 @@ public:
                     const std::string& sk = std::string()) const = 0;
     virtual int set(const std::string& nm, const std::string& val,
                     const std::string& sk = std::string()) = 0;
+    virtual long long getInt(const std::string& name, long long dflt,
+                             const std::string& sk = std::string());
+    virtual double getFloat(const std::string& name, double dflt,
+                            const std::string& sk = std::string());
+    virtual bool getBool(const std::string& name, bool dflt,
+                         const std::string& sk = std::string());
     virtual bool ok() const = 0;
     virtual std::vector<std::string> getNames(const std::string& sk,
-                                              const char* = 0)const = 0;
+                                              const char* = 0) const = 0;
     virtual bool hasNameAnywhere(const std::string& nm) const = 0;
     virtual int erase(const std::string&, const std::string&) = 0;
     virtual int eraseKey(const std::string&) = 0;
@@ -167,15 +171,6 @@ public:
     virtual int get(const std::string& name, std::string& value,
                     const std::string& sk = std::string()) const override;
 
-    /**
-     * Get integer value for named parameter, from specified subsection (looks 
-     * in global space if sk is empty).
-     * @return 0 if name not found, 1 else
-     */
-    virtual int get(const std::string& name, int* value,
-                    const std::string& sk = std::string()) const;
-
-
     /**
      * Set value for named string parameter in specified subsection (or global)
      * @return 0 for error, 1 else
@@ -223,7 +218,8 @@ public:
     /** Print all values to stdout */
     virtual void showall() const override;
 
-    /** Return all names in given submap. */
+    /** Return all names in given submap. On win32, the pattern thing
+        only works in recoll builds */
     virtual std::vector<std::string> getNames(
         const std::string& sk, const char *pattern = 0) const override;
 
@@ -302,8 +298,8 @@ protected:
     StatusCode status;
 private:
     // Set if we're working with a file
-    std::string                            m_filename;
-    time_t                            m_fmtime;
+    std::string m_filename;
+    int64_t     m_fmtime;
     // Configuration data submaps (one per subkey, the main data has a
     // null subkey)
     std::map<std::string, std::map<std::string, std::string> > m_submaps;
@@ -311,9 +307,9 @@ private:
     // Presentation data. We keep the comments, empty lines and
     // variable and subkey ordering information in there (for
     // rewriting the file while keeping hand-edited information)
-    std::vector<ConfLine>                    m_order;
+    std::vector<ConfLine>    m_order;
     // Control if we're writing to the backing store
-    bool                              m_holdWrites;
+    bool                     m_holdWrites;
 
     void parseinput(std::istream& input);
     bool write();
@@ -369,15 +365,16 @@ public:
 };
 
 /**
- * Use several config files, trying to get values from each in order. Used to
- * have a central config, with possible overrides from more specific
- * (ie personal) ones.
+ * Use several config files, trying to get values from each in order. 
+ *
+ * Enables having a central/default config, with possible overrides
+ * from more specific (e.g. personal) ones.
  *
  * Notes: it's ok for some of the files not to exist, but the last
- * one must or we generate an error. We open all trees readonly, except the
- * topmost one if requested. All writes go to the topmost file. Note that
- * erase() won't work except for parameters only defined in the topmost
- * file (it erases only from there).
+ * (bottom) one must or we generate an error. We open all trees
+ * readonly, except the topmost one if requested. All writes go to the
+ * topmost file. Note that erase() won't work except for parameters
+ * only defined in the topmost file (it erases only from there).
  */
 template <class T> class ConfStack : public ConfNull {
 public:
@@ -418,7 +415,7 @@ public:
         return *this;
     }
 
-     virtual bool sourceChanged() const override {
+    virtual bool sourceChanged() const override {
         for (const auto& conf : m_confs) {
             if (conf->sourceChanged()) {
                 return true;
@@ -495,12 +492,14 @@ public:
         return m_confs.front()->holdWrites(on);
     }
 
+    /** Return all names in given submap. On win32, the pattern thing
+        only works in recoll builds */
     virtual std::vector<std::string> getNames(
         const std::string& sk, const char *pattern = 0) const override {
         return getNames1(sk, pattern, false);
     }
     virtual std::vector<std::string> getNamesShallow(const std::string& sk,
-                                           const char *patt = 0) const {
+                                                     const char *patt = 0) const {
         return getNames1(sk, patt, true);
     }
 
