@@ -36,7 +36,7 @@ void     MD5Transform(uint32_t [4], const uint8_t [MD5_BLOCK_LENGTH]);
 #include <string>
 extern void MD5Final(std::string& digest, MD5_CTX *);
 extern std::string& MD5String(const std::string& data, std::string& digest);
-extern std::string& MD5HexPrint(const std::string& digest, std::string& xdigest);
+extern std::string& MD5HexPrint(const std::string& digest, std::string& out);
 extern std::string& MD5HexScan(const std::string& xdigest, std::string& digest);
 
 #endif /* _MD5_H_ */
