@@ -56,7 +56,6 @@
 
 #include <cstdlib>
 #include <cstring>
-#include <dirent.h>
 #include <errno.h>
 #include <fstream>
 #include <iostream>
@@ -69,9 +68,16 @@
 #include <vector>
 #include <fcntl.h>
 
-#ifndef PRETEND_USE
-#define PRETEND_USE(expr) ((void)(expr))
-#endif
+// Listing directories: we include the normal dirent.h on Unix-derived
+// systems, and on MinGW, where it comes with a supplemental wide char
+// interface. When building with MSVC, we use our bundled msvc_dirent.h,
+// which is equivalent to the one in MinGW
+#ifdef _MSC_VER
+#include "msvc_dirent.h"
+#else // !_MSC_VER
+#include <dirent.h>
+#endif // _MSC_VER
+
 
 #ifdef _WIN32
 
@@ -88,12 +94,12 @@
 #endif
 #define WIN32_LEAN_AND_MEAN
 #define NOGDI
-#define MAXPATHLEN PATH_MAX
-
 #include <windows.h>
 #include <io.h>
-
 #include <sys/stat.h>
+#include <direct.h>
+#include <Shlobj.h>
+#include <Stringapiset.h>
 
 #if !defined(S_IFLNK)
 #define S_IFLNK 0
@@ -104,33 +110,44 @@
 #ifndef S_ISREG
 # define S_ISREG(ST_MODE) (((ST_MODE) & _S_IFMT) == _S_IFREG)
 #endif
-
-#include <direct.h>
-
-#include <Shlobj.h>
-#include <Stringapiset.h>
+#define MAXPATHLEN PATH_MAX
+#ifndef PATH_MAX
+#define PATH_MAX MAX_PATH
+#endif
+#ifndef R_OK
+#define R_OK 4
+#endif
 
 #define STAT _wstati64
 #define LSTAT _wstati64
 #define STATBUF _stati64
 #define ACCESS _waccess
-#define OPENDIR _wopendir
+#define OPENDIR ::_wopendir
+#define DIRHDL _WDIR
 #define CLOSEDIR _wclosedir
-#define READDIR _wreaddir
+#define READDIR ::_wreaddir
+#define REWINDDIR ::_wrewinddir
 #define DIRENT _wdirent
 #define DIRHDL _WDIR
 #define MKDIR(a,b) _wmkdir(a)
 #define OPEN ::_wopen
 #define UNLINK _wunlink
+#define RMDIR _wrmdir
 #define CHDIR _wchdir
 
+#define SYSPATH(PATH, SPATH) wchar_t PATH ## _buf[2048];      \
+    utf8towchar(PATH, PATH ## _buf, 2048);                    \
+    wchar_t *SPATH = PATH ## _buf;
+
 #define ftruncate _chsize_s
 
 #ifdef _MSC_VER
 // For getpid
 #include <process.h>
 #define getpid _getpid
-#endif
+
+#define PATHUT_SSIZE_T int
+#endif // _MSC_VER
 
 #else /* !_WIN32 -> */
 
@@ -146,21 +163,32 @@
 #define LSTAT lstat
 #define STATBUF stat
 #define ACCESS access
-#define OPENDIR opendir
+#define OPENDIR ::opendir
+#define DIRHDL DIR
 #define CLOSEDIR closedir
-#define READDIR readdir
+#define READDIR ::readdir
+#define REWINDDIR ::rewinddir
 #define DIRENT dirent
 #define DIRHDL DIR
 #define MKDIR(a,b) mkdir(a,b)
 #define O_BINARY 0
 #define OPEN ::open
 #define UNLINK ::unlink
+#define RMDIR ::rmdir
 #define CHDIR ::chdir
 
+#define SYSPATH(PATH, SPATH) const char *SPATH = PATH.c_str()
+
+
 #endif /* !_WIN32 */
 
 using namespace std;
 
+#ifndef PATHUT_SSIZE_T
+#define PATHUT_SSIZE_T ssize_t
+#endif
+
+
 #ifdef _WIN32
 
 std::string wchartoutf8(const wchar_t *in, size_t len)
@@ -236,6 +264,31 @@ bool utf8towchar(const std::string& in, wchar_t *out, size_t obytescap)
     return true;
 }
 
+std::unique_ptr<wchar_t[]> utf8towchar(const std::string& in)
+{
+    // Note that as we supply in.size(), mbtowch computes the size
+    // without a terminating 0 (and won't write in the second call of
+    // course). We take this into account by allocating one more and
+    // terminating the output.
+    int wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), in.size(), nullptr, 0);
+    if (wcharcnt <= 0) {
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+        return std::unique_ptr<wchar_t[]>();
+    }
+    auto buf = unique_ptr<wchar_t[]>(new wchar_t[wcharcnt+1]);
+
+    wcharcnt = MultiByteToWideChar(
+        CP_UTF8, MB_ERR_INVALID_CHARS, in.c_str(), in.size(),
+        buf.get(), wcharcnt);
+    if (wcharcnt <= 0) {
+        LOGERR("utf8towchar: conversion error for [" << in << "]\n");
+        return std::unique_ptr<wchar_t[]>();
+    }
+    buf.get()[wcharcnt] = 0;
+    return buf;
+}
+
 /// Convert \ separators to /
 void path_slashize(string& s)
 {
@@ -631,28 +684,6 @@ string path_home()
 #endif
 }
 
-// The default place to store the default config and other stuff (e.g webqueue)
-string path_homedata()
-{
-#ifdef _WIN32
-    wchar_t *cp;
-    SHGetKnownFolderPath(FOLDERID_LocalAppData, 0, nullptr, &cp);
-    string dir;
-    if (cp != 0) {
-        wchartoutf8(cp, dir);
-    }
-    if (!dir.empty()) {
-        dir = path_canon(dir);
-    } else {
-        dir = path_cat(path_home(), "AppData/Local/");
-    }
-    return dir;
-#else
-    // We should use an xdg-conforming location, but, history...
-    return path_home();
-#endif
-}
-
 string path_tildexpand(const string& s)
 {
     if (s.empty() || s[0] != '~') {
@@ -742,11 +773,7 @@ string path_absolute(const string& is)
     path_slashize(s);
 #endif
     if (!path_isabsolute(s)) {
-        char buf[MAXPATHLEN];
-        if (!getcwd(buf, MAXPATHLEN)) {
-            return string();
-        }
-        s = path_cat(string(buf), s);
+        s = path_cat(path_cwd(), s);
 #ifdef _WIN32
         path_slashize(s);
 #endif
@@ -769,16 +796,11 @@ string path_canon(const string& is, const string* cwd)
 #endif
 
     if (!path_isabsolute(s)) {
-        char buf[MAXPATHLEN];
-        const char *cwdp = buf;
         if (cwd) {
-            cwdp = cwd->c_str();
+            s = path_cat(*cwd, s);
         } else {
-            if (!getcwd(buf, MAXPATHLEN)) {
-                return string();
-            }
+            s = path_cat(path_cwd(), s);
         }
-        s = path_cat(string(cwdp), s);
     }
     vector<string> elems;
     stringToTokens(s, elems, "/");
@@ -857,35 +879,40 @@ bool path_chdir(const std::string& path)
     return CHDIR(syspath) == 0;
 }
 
+std::string path_cwd()
+{
+#ifdef _WIN32
+    wchar_t *wd = _wgetcwd(nullptr, 0);
+    if (nullptr == wd) {
+        return std::string();
+    }
+    string sdname;
+    wchartoutf8(wd, sdname);
+    free(wd);
+    path_slashize(sdname);
+    return sdname;
+#else
+    char wd[MAXPATHLEN+1];
+    if (nullptr == getcwd(wd, MAXPATHLEN+1)) {
+        return string();
+    }
+    return wd;
+#endif
+}
+
 bool path_unlink(const std::string& path)
 {
     SYSPATH(path, syspath);
     return UNLINK(syspath) == 0;
 }
 
-#if !defined(__GNUC__) || __GNUC__ > 4 || defined(__clang__)
-// Not sure what g++ version supports fstream assignment but 4.9
-// (jessie) certainly does not
-std::fstream path_open(const std::string& path, int mode)
+bool path_rmdir(const std::string& path)
 {
-#if defined(_WIN32) && defined (_MSC_VER)
-    // MSC STL has support for using wide chars in fstream
-    // constructor. We need this if, e.g. the user name/home directory
-    // is not ASCII. Actually don't know how to do this with gcc
-    wchar_t wpath[MAX_PATH + 1];
-    utf8towchar(path, wpath, MAX_PATH);
-    std::fstream ret(wpath, std::ios_base::openmode(mode));
-    if (!ret.is_open()) {
-        LOGERR("path_open("<< path << ", "<< mode <<") errno " << errno <<"\n");
-    }
-    return ret;
-#else
-    return std::fstream(path, std::ios_base::openmode(mode));
-#endif
+    SYSPATH(path, syspath);
+    return RMDIR(syspath) == 0;
 }
-#endif
 
-bool path_open(const std::string& path, int mode, std::fstream& outstream)
+bool path_streamopen(const std::string& path, int mode, std::fstream& outstream)
 {
 #if defined(_WIN32) && defined (_MSC_VER)
     // MSC STL has support for using wide chars in fstream
@@ -894,15 +921,13 @@ bool path_open(const std::string& path, int mode, std::fstream& outstream)
     wchar_t wpath[MAX_PATH + 1];
     utf8towchar(path, wpath, MAX_PATH);
     outstream.open(wpath, std::ios_base::openmode(mode));
+#else
+    outstream.open(path, std::ios_base::openmode(mode));
+#endif
     if (!outstream.is_open()) {
-        LOGERR("path_open("<< path << ", "<< mode <<") errno " << errno <<"\n");
         return false;
     }
     return true;
-#else
-    outstream.open(path, std::ios_base::openmode(mode));
-    return outstream.is_open();
-#endif
 }
 
 bool path_isdir(const string& path, bool follow)
@@ -943,6 +968,26 @@ long long path_filesize(const string& path)
     return (long long)st.st_size;
 }
 
+bool path_samefile(const std::string& p1, const std::string& p2)
+{
+#ifdef _WIN32
+    std::string cp1, cp2;
+    cp1 = path_canon(p1);
+    cp2 = path_canon(p2);
+    return !cp1.compare(cp2);
+#else
+    struct stat st1, st2;
+    if (stat(p1.c_str(), &st1))
+        return false;
+    if (stat(p2.c_str(), &st2))
+        return false;
+    if (st1.st_dev == st2.st_dev && st1.st_ino == st2.st_ino) {
+        return true;
+    }
+    return false;
+#endif
+}
+
 int path_fileprops(const std::string path, struct PathStat *stp, bool follow)
 {
     if (nullptr == stp) {
@@ -986,6 +1031,11 @@ bool path_readable(const string& path)
     SYSPATH(path, syspath);
     return ACCESS(syspath, R_OK) == 0;
 }
+bool path_access(const std::string& path, int mode)
+{
+    SYSPATH(path, syspath);
+    return ACCESS(syspath, mode) == 0;
+}
 
 /* There is a lot of vagueness about what should be percent-encoded or
  * not in a file:// url. The constraint that we have is that we may use
@@ -1250,56 +1300,108 @@ ParsedUri::ParsedUri(std::string uri)
     }
 }
 
+/// Directory reading interface. UTF-8 on Windows.
+class PathDirContents::Internal {
+public:
+    ~Internal() {
+        if (dirhdl) {
+            CLOSEDIR(dirhdl);
+        }
+    }
+        
+    DIRHDL *dirhdl{nullptr};
+    PathDirContents::Entry entry;
+    std::string dirpath;
+};
+
+PathDirContents::PathDirContents(const std::string& dirpath)
+{
+    m = new Internal;
+    m->dirpath = dirpath;
+}
+
+PathDirContents::~PathDirContents()
+{
+    delete m;
+}
+
+bool PathDirContents::opendir()
+{
+    if (m->dirhdl) {
+        CLOSEDIR(m->dirhdl);
+        m->dirhdl = nullptr;
+    }
+    const std::string& dp{m->dirpath};
+    SYSPATH(dp, sysdir);
+    m->dirhdl = OPENDIR(sysdir);
+#ifdef _WIN32
+    if (nullptr == m->dirhdl) {
+        int rc = GetLastError();
+        LOGERR("opendir failed: LastError " << rc << endl);
+        if (rc == ERROR_NETNAME_DELETED) {
+            // 64: share disconnected.
+            // Not too sure of the errno in this case.
+            // Make sure it's not one of the permissible ones
+            errno = ENODEV;
+        }
+    }
+#endif
+    return nullptr != m->dirhdl;
+}
+
+void PathDirContents::rewinddir()
+{
+    REWINDDIR(m->dirhdl);
+}
+
+const struct PathDirContents::Entry* PathDirContents::readdir()
+{
+    struct DIRENT *ent = READDIR(m->dirhdl);
+    if (nullptr == ent) {
+        return nullptr;
+    }
+#ifdef _WIN32
+    string sdname;
+    if (!wchartoutf8(ent->d_name, sdname)) {
+        LOGERR("wchartoutf8 failed for " << ent->d_name << endl);
+        return nullptr;
+    }
+    const char *dname = sdname.c_str();
+#else
+    const char *dname = ent->d_name;
+#endif
+    m->entry.d_name = dname;
+    return &m->entry;
+}
+
+
 bool listdir(const string& dir, string& reason, set<string>& entries)
 {
-    struct STATBUF st;
-    int statret;
     ostringstream msg;
-    DIRHDL *d = 0;
-
-    SYSPATH(dir, sysdir);
-
-    statret = LSTAT(sysdir, &st);
-    if (statret == -1) {
-        msg << "listdir: cant stat " << dir << " errno " <<  errno;
-        goto out;
-    }
-    if (!S_ISDIR(st.st_mode)) {
+    PathDirContents dc(dir);
+    
+    if (!path_isdir(dir)) {
         msg << "listdir: " << dir <<  " not a directory";
         goto out;
     }
-    if (ACCESS(sysdir, R_OK) < 0) {
+    if (!path_access(dir, R_OK)) {
         msg << "listdir: no read access to " << dir;
         goto out;
     }
 
-    d = OPENDIR(sysdir);
-    if (d == 0) {
+    if (!dc.opendir()) {
         msg << "listdir: cant opendir " << dir << ", errno " << errno;
         goto out;
     }
-
-    struct DIRENT *ent;
-    while ((ent = READDIR(d)) != 0) {
-#ifdef _WIN32
-        string sdname;
-        if (!wchartoutf8(ent->d_name, sdname)) {
+    const struct PathDirContents::Entry *ent;
+    while ((ent = dc.readdir()) != 0) {
+        if (ent->d_name == "." || ent->d_name == "..") {
             continue;
         }
-        const char *dname = sdname.c_str();
-#else
-        const char *dname = ent->d_name;
-#endif
-        if (!strcmp(dname, ".") || !strcmp(dname, "..")) {
-            continue;
-        }
-        entries.insert(dname);
+        entries.insert(ent->d_name);
     }
 
 out:
-    if (d) {
-        CLOSEDIR(d);
-    }
     reason = msg.str();
     if (reason.empty()) {
         return true;
@@ -1401,7 +1503,7 @@ int Pidfile::write_pid()
     char pidstr[20];
     sprintf(pidstr, "%u", int(getpid()));
     lseek(m_fd, 0, 0);
-    if (::write(m_fd, pidstr, strlen(pidstr)) != (ssize_t)strlen(pidstr)) {
+    if (::write(m_fd, pidstr, strlen(pidstr)) != (PATHUT_SSIZE_T)strlen(pidstr)) {
         m_reason = "write failed";
         return -1;
     }
