@@ -22,10 +22,10 @@
 #include <stdlib.h>
 #include "safefcntl.h"
 #include "safeunistd.h"
-#include "dirent.h"
 #include "cstr.h"
 #ifdef _WIN32
 #include "safewindows.h"
+#include <Shlobj.h>
 #else
 #include <sys/param.h>
 #include <pwd.h>
@@ -41,6 +41,7 @@
 #include <unordered_map>
 #include <list>
 #include <vector>
+#include <numeric>
 
 #include "rclutil.h"
 #include "pathut.h"
@@ -66,6 +67,24 @@ template void map_ss_cp_noshr<map<string, string> >(
 template void map_ss_cp_noshr<unordered_map<string, string> >(
     unordered_map<string,string> s, unordered_map<string,string>*d);
 
+// Add data to metadata field, store multiple values as CSV, avoid
+// appending multiple identical instances.
+template <class T> void addmeta(
+    T& store, const string& nm, const string& value)
+{
+    auto it = store.find(nm);
+    if (it == store.end() || it->second.empty()) {
+        store[nm] = value;
+    } else if (it->second.find(value) == string::npos) {
+        store[nm] += ',';
+        store[nm] += value;
+    }
+}
+template void addmeta<map<string, string>>(
+    map<string, string>&, const string&, const string&);
+template void addmeta<unordered_map<string, string>>(
+    unordered_map<string, string>&, const string&, const string&);
+
 #ifdef _WIN32
 static bool path_hasdrive(const string& s)
 {
@@ -177,6 +196,28 @@ static bool path_gettempfilename(string& filename, string& reason)
 }
 #endif // posix
 
+// The default place to store the default config and other stuff (e.g webqueue)
+string path_homedata()
+{
+#ifdef _WIN32
+    wchar_t *cp;
+    SHGetKnownFolderPath(FOLDERID_LocalAppData, 0, nullptr, &cp);
+    string dir;
+    if (cp != 0) {
+        wchartoutf8(cp, dir);
+    }
+    if (!dir.empty()) {
+        dir = path_canon(dir);
+    } else {
+        dir = path_cat(path_home(), "AppData/Local/");
+    }
+    return dir;
+#else
+    // We should use an xdg-conforming location, but, history...
+    return path_home();
+#endif
+}
+
 // Check if path is either non-existing or an empty directory.
 bool path_empty(const string& path)
 {
@@ -452,7 +493,7 @@ TempFile::Internal::Internal(const string& suffix)
     }
     m_filename += suffix;
     std::fstream fout;
-    if (!path_open(m_filename, ios::out|ios::trunc, fout)) {
+    if (!path_streamopen(m_filename, ios::out|ios::trunc, fout)) {
         m_reason = string("Open/create error. errno : ") +
             lltodecstr(errno) + " file name: " + m_filename;
         LOGSYSERR("Tempfile::Internal::Internal", "open/create", m_filename);
@@ -608,9 +649,72 @@ bool thumbPathForUrl(const string& url, int size, string& path)
     return false;
 }
 
+// Compare charset names, removing the more common spelling variations
+bool samecharset(const string& cs1, const string& cs2)
+{
+    auto mcs1 = std::accumulate(cs1.begin(), cs1.end(), "", [](const char* m, char i) { return (i != '_' && i != '-') ? m + ::tolower(i) : m; });
+    auto mcs2 = std::accumulate(cs2.begin(), cs2.end(), "", [](const char* m, char i) { return (i != '_' && i != '-') ? m + ::tolower(i) : m; });
+    return mcs1 == mcs2;
+}
+
+static const std::unordered_map<string, string> lang_to_code {
+    {"be", "cp1251"},
+    {"bg", "cp1251"},
+    {"cs", "iso-8859-2"},
+    {"el", "iso-8859-7"},
+    {"he", "iso-8859-8"},
+    {"hr", "iso-8859-2"},
+    {"hu", "iso-8859-2"},
+    {"ja", "eucjp"},
+    {"kk", "pt154"},
+    {"ko", "euckr"},
+    {"lt", "iso-8859-13"},
+    {"lv", "iso-8859-13"},
+    {"pl", "iso-8859-2"},
+    {"rs", "iso-8859-2"},
+    {"ro", "iso-8859-2"},
+    {"ru", "koi8-r"},
+    {"sk", "iso-8859-2"},
+    {"sl", "iso-8859-2"},
+    {"sr", "iso-8859-2"},
+    {"th", "iso-8859-11"},
+    {"tr", "iso-8859-9"},
+    {"uk", "koi8-u"},
+        };
+
+string langtocode(const string& lang)
+{
+    const auto it = lang_to_code.find(lang);
+
+    // Use cp1252 by default...
+    if (it == lang_to_code.end()) {
+        return cstr_cp1252;
+    }
+
+    return it->second;
+}
+
+string localelang()
+{
+    const char *lang = getenv("LANG");
+
+    if (lang == nullptr || *lang == 0 || !strcmp(lang, "C") ||
+        !strcmp(lang, "POSIX")) {
+        return "en";
+    }
+    string locale(lang);
+    string::size_type under = locale.find_first_of('_');
+    if (under == string::npos) {
+        return locale;
+    }
+    return locale.substr(0, under);
+}
+
 void rclutil_init_mt()
 {
     path_pkgdatadir();
     tmplocation();
     thumbnailsdir();
+    // Init langtocode() static table
+    langtocode("");
 }
